package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$"`0,````````````"``\````!``$;M````#0``-UX```"$``T`"``
M!P`H`!P`&P````8````T``$`-``!`#0```#@````X`````4````$`````P``
M`10``0$4``$!%`````T````-````!`````$````!```````!`````0````#6
M<```UG`````%```0``````$``-9P``'F<``!YG````/\```41`````<``!``
M`````@``UH0``>:$``'FA````/````#P````!@````0````$```!)``!`20`
M`0$D````(````"`````$````!&1TY5```-8H``'6*``!UB@````4````%```
M``0````$+VQI8B]L9"YS;RXQ``````````0````0`````4=.50``````````
M`@````8````)````80```',````2``````````````!?`````````&H```!I
M``````````````!3````6@```$\```!!````1P```#0`````````20```&\`
M```#````.0```&,````;````10```$,``````````````%$```!7````.P``
M``````!8````&````&4```!-````$0````````!N````<````$0```!R````
M`````&(`````````8`````````!A````5``````````C````"@```%(`````
M````,0``````````````0@```!`````X````:```````````````2P``````
M``!;```````````````W`````````%T````N````$P```$````!M````!P``
M````````````"````"P```!5````,````'$````H````3``````````5````
M```````````Z````1@```%P`````````9````!H```!>````9P```&P`````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````&````#0``
M````````````````````````````%P`````````````````````````,````
M``````X````````````````````9````````````````````%``````````$
M````)@```"(``````````@```"\````?````````````````````````````
M```S```````````````R````-@````D``````````0````\`````````!0``
M`!T`````````````````````````````````````````(0```#X````M````
M/P```!8````E```````````````<````(````"<`````````4``````````U
M`````````"L```!*```````````````I````60``````````````````````
M```]````'@```%8````J````2`````````!F````/````"0`````````````
M`$X```!K````"P````````````````````````4/``'G=``````@```5```$
MV@````````*D$@``````!%0``26@````*!(```L```1E``$HP````(02```+
M````)P`````````($@```````#X`````````*!(```````01``'J<`````0A
M```8```$<@`!<FP````$$@``"P```\8`````````%!(```````43``$;M```
M`%`2```+````2`````````5<$@```````TP`````````F!(```````!3````
M`````$P2```````"_`````````"H$@```````YP````````!%!(```````!F
M``%U$`````0B```+````=0``````````(````````(D`````````"!(`````
M``09`````````&`2```````"&`````````64$@```````)T`````````"!(`
M``````"O``````````@2```````$?``!=10`````$@``#```!((``66X```&
M^!(```L```,E`````````O02```````$F``!+3P```"<$@``"P``!*8``21H
M```!.!(```L```00``'J<`````0A```8```"[0````````"@$@```````Z,`
M````````3!(```````"\````````!%@2```````#AP````````#`$@``````
M`,4````````#K!(```````#3`````````'`2````````$0`!ZDP`````$0#_
M\0``!+P``2E$```"`!(```L```3(``%5+````%P2```+````XP````````&8
M$@``````!.,``6%(````J!(```L```/G`````````902```````#1```````
M``#($@``````!.\``>>,````!!$``!4```#Q`````````=@2```````%:0`!
M>+```%JX$0``#0``!/X``750````!!$```T```#\``````````P2```````#
MS0````````!,$@``````!`\``>IP````!!$``!@```$0`````````V02````
M```$(P````````!@$@```````W(````````!'!(```````4-``'G=``````0
M```5```!'@`````````($@```````3``````````F!(```````.X````````
M`$`2```````#:@````````2X$@```````3X````````*'!(```````4:``'G
M=``````1```5```#@`````````!L$@```````4X`````````3!(```````/V
M`````````"@2```````!7P````````&,$@```````7`````````&3!(`````
M``/=`````````E`2```````#-P````````$,$@``````!2,``1T`````=!(`
M``L```%_`````````902```````#/``````````\$@```````V0`````````
M3!(```````4K``%R<````*@2```+```#>0````````!H$@```````8X`````
M```#,!(```````&<````````$@02```````$0P`!ZFP`````$`#_\0```U4`
M````````V!(```````&J`````````102```````#E0````````#($@``````
M`;8`````````"!(```````''``````````@2```````#_0````````*($@``
M`````UT`````````3!(```````/6````````!0P2```````#`@````````"$
M$@``````!3L``64H````D!(```L```'9`````````%P2```````![@``````
M```($@``````!$\``?JT`````!``__$```57``%?L````9@2```+```#%@``
M``````"X$@```````@P`````````@!(```````(?`````````+@2```````%
M9``!YX@````$$0``%0```$,````````"-!(```````+U`````````3`2````
M```"+``````````($@```````CX``>IX````$Q$``!@```5S``%7$```"*`2
M```+```#[P````````!,$@``````!#P``>IL`````!``__$```)-````````
M`P`2```````%@``!58@```&($@``"P``!9(``27(```"^!(```L```.P````
M`````1`2```````"6`````````!P$@```````F<`````````#!(```````)Y
M``````````@2```````"C@`````````($@```````ZD`````````X!(`````
M``..`````````+02```````%GP`!*T0```'X$@``"P``!`H``6U4```$\!(`
M``L```4E``$6[``````2```*```"GP````````",$@```````K8````````(
M%!(`````;&EB<&5R;"YS;RXU+C$P`%]'3$]"04Q?3T9&4T547U1!0DQ%7P!0
M97)L7TEC=7)S=&%C:VEN9F]?<'1R`'!E<FQ?9G)E90!P97)L7W!A<G-E`%!E
M<FQ?871F;W)K7W5N;&]C:P!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#
M;&%S<V5S`%!E<FQ?265V86Q?<F]O=%]P='(`4&5R;%]):6Y?979A;%]P='(`
M4&5R;%]);W!?<'1R`'!E<FQ?<G5N`%!E<FQ?879?<VAI9G0`4&5R;%]G=E]F
M971C:'!V`%!E<FQ?<W9?<V5T<'8`<&5R;%]A;&QO8P!097)L7T=D;U]U;F1U
M;7!?<'1R`%!E<FQ?9&]U;G=I;F0`4&5R;%])=&%I;G1E9%]P='(`4&5R;%]S
M>7-?=&5R;0!B;V]T7T1Y;F%,;V%D97(`4&5R;%]A=&9O<FM?;&]C:P!097)L
M7VYE=UA37V9L86=S`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?<W9?<V5T<'9N`%!E
M<FQ?879?9F5T8V@`<&5R;%]D97-T<G5C=`!097)L7VUG7W-E=`!097)L7TEP
M87)S97)?<'1R`%!E<FQ?27-T871B=69?<'1R`%!E<FQ?8W)O86M?;F]C;VYT
M97AT`%!E<FQ?27!E<FQ?9&5S=')U8W1?;&5V96Q?<'1R`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!097)L7VYE=U-6<'8`4&5R;%])=&]P7V5N=E]P='(`4$Q?;65M
M;W)Y7W=R87``4&5R;%]N97=84P!097)L7W-Y<U]I;FET,P!097)L7T=T:')?
M:V5Y7W!T<@!097)L7TEE>&ET7V9L86=S7W!T<@!097)L7TEC;VUP8W9?<'1R
M`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%]S=E\R<'9?9FQA9W,`;&EB
M9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`&QS965K-C0`;W!E
M;C8T`&-L;W-E`'!T:')E861?9V5T<W!E8VEF:6,`<F5A9`!L:6)C+G-O+C8`
M7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S<')I;G1F`'-T<FYC;7``8VQO<V5D
M:7(`<W1R;F-P>0!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED
M`'-T<F1U<`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`;65M
M8W!Y`&]P96YD:7(`7U]C='EP95]B7VQO8P!G971U:60`<F5A9&QI;FL`97AE
M8W9P`')E861D:7(V-`!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T
M87)T7VUA:6X`7U]E;G9I<F]N`%]?>'-T870V-`!?7VQX<W1A=#8T`&QI8F-R
M>7!T+G-O+C$`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`<&%R7V-U<G)E;G1?
M97AE8P!P87)?8F%S96YA;64`7U]L:6)C7V-S=5]F:6YI`%A37TEN=&5R;F%L
M<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O
M8P!P87)?9&ER;F%M90!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?
M8VQE86YU<`!S:7IE7VQO861?;65?,@!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?
M<W1A<G0`)&=L;V)A;"0`>'-?:6YI=`!?7VQI8F-?8W-U7VEN:70`6%-?26YT
M97)N86QS7U!!4E]#3$5!4E-404-+`'!A<E]R;71M<&1I<@!N86UE7VQO861?
M;65?,@!P87)?;6MT;7!D:7(`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P
M<F]G`'!A<E]I;FET7V5N=@!'3$E"0U\R+C(`1TQ)0D-?,BXS`$=,24)#7S(N
M,RXR``````$``@`!``$```````(``0`"``$````"`````P`"``$```````(`
M`@```````0`!``0``0`!``(``P`"`````@```````0`!``$````!``(``@`!
M`````0`!`````@`"`````@`"``$```````4``@````$``@````(```````(`
M`@`!`````@`"``$``@```````0`"`````@```````@`"``(``P`!```````!
M``$``P```````0`"``,```````$``@`!`````0`!``(````````````"``(`
M`0`!``$``````````0`!```"W0```!`````@#6EI$@````,```6L```````!
M``,```,;````$``````-:6D3````!0``!;8````0"6D9<@````0```7`````
M$`UI:1(````"```%K````````>I<```C`0```````>IP```P@````````>IX
M``!@@````````>>@```"@0```````>>H```%@0```````>>P```&@0``````
M`>>X```(@0```````>?````)@0```````>?(```+@0```````>?0```,@0``
M`````>?8```-@0```````>?@```.@0```````>?H```/@0```````>?P```0
M@0```````>?X```1@0```````>@````2@0```````>@(```3@0```````>@0
M```4@0```````>@8```5@0```````>@@```6@0```````>@H```8@0``````
M`>@P```9@0```````>@X```=@0```````>A````>@0```````>A(```?@0``
M`````>A0```@@0```````>A8```A@0```````>A@```B@0```````>AH```F
M@0```````>AP```H@0```````>AX```I@0```````>B````K@0```````>B(
M```N@0```````>B0```O@0```````>B8```Q@0```````>B@```R@0``````
M`>BH```S@0```````>BP```U@0```````>BX```V@0```````>C````W@0``
M`````>C(```X@0```````>C0```Y@0```````>C8```[@0```````>C@```\
M@0```````>CH```]@0```````>CP```^@0```````>CX```_@0```````>D`
M``!`@0```````>D(``!!@0```````>D0``!#@0```````>D8``!$@0``````
M`>D@``!%@0```````>DH``!&@0```````>DP``!'@0```````>DX``!(@0``
M`````>E```!)@0```````>E(``!+@0```````>E0``!,@0```````>E8``!-
M@0```````>E@``!.@0```````>EH``!/@0```````>EP``!0@0```````>EX
M``!1@0```````>F```!2@0```````>F(``!3@0```````>F0``!5@0``````
M`>F8``!6@0```````>F@``!9@0```````>FH``!:@0```````>FP``!;@0``
M`````>FX``!=@0```````>G```!>@0```````>G(``!?@0```````>G0``!B
M@0```````>G8``!D@0```````>G@``!G@0```````>GH``!H@0```````>GP
M``!I@0```````>GX``!J@0```````>H```!K@0```````>H(``!L@0``````
M`>H0``!M@0```````>H8``!O@0```````>H@``!Q@0```````>HH``!R@0``
M```K8```2#4`^.J@P`!(,P$`:\(_V6_$`(!KTS_!Z%\?O0@3`D0(!`)3Z$`+
M2`@``D#H0AKD"``"0$O"/UD(!`)3Z$#``$_$/X$K8```2#4#R.J@P`!(,P/0
M*V```$@U!-CJH,``2#,$X"M@``!(-0-8ZJ#``$@S`V`K8```2#4$*.J@P`!(
M,P0P*V```$@U`&CJH,``2#,`<"M@``!(-0(8ZJ#``$@S`B`K8```2#4$>.J@
MP`!(,P2`*V```$@U`@CJH,``2#,"$"M@``!(-01HZJ#``$@S!'`K8```2#4#
M^.J@P`!(,P0`*V```$@U`%CJH,``2#,`8"M@``!(-0)8ZJ#``$@S`F`K8```
M2#4$2.J@P`!(,P10*V```$@U!+CJH,``2#,$P"M@``!(-0"HZJ#``$@S`+`K
M8```2#4#J.J@P`!(,P.P*V```$@U`LCJH,``2#,"T"M@``!(-0'(ZJ#``$@S
M`=`K8```2#4!Z.J@P`!(,P'P*V```$@U`+CJH,``2#,`P"M@``!(-0-XZJ#`
M`$@S`X`K8```2#4!>.J@P`!(,P&`*V```$@U!5CJH,``2#,%8"M@``!(-0+H
MZJ#``$@S`O`K8```2#4$B.J@P`!(,P20*V```$@U!3CJH,``2#,%0"M@``!(
M-0,8ZJ#``$@S`R`K8```2#4$R.J@P`!(,P30*V```$@U`=CJH,``2#,!X"M@
M``!(-0(HZJ#``$@S`C`K8```2#4">.J@P`!(,P*`*V```$@U`RCJH,``2#,#
M,"M@``!(-0-(ZJ#``$@S`U`K8```2#4$Z.J@P`!(,P3P*V```$@U`'CJH,``
M2#,`@"M@``!(-0*8ZJ#``$@S`J`K8```2#4`Z.J@P`!(,P#P*V```$@U!!CJ
MH,``2#,$("M@``!(-0/HZJ#``$@S`_`K8```2#4!^.J@P`!(,P(`*V```$@U
M`JCJH,``2#,"L"M@``!(-0.8ZJ#``$@S`Z`K8```2#4#B.J@P`!(,P.0*V``
M`$@U!*CJH,``2#,$L"M@``!(-05HZJ#``$@S!7`K8```2#4$^.J@P`!(,P4`
M*V```$@U`3CJH,``2#,!0"M@``!(-0,XZJ#``$@S`T`K8```2#4$6.J@P`!(
M,P1@*V```$@U!)CJH,``2#,$H"M@``!(-0$HZJ#``$@S`3`K8```2#4!N.J@
MP`!(,P'`*V```$@U`DCJH,``2#,"4"M@``!(-0/8ZJ#``$@S`^`K8```2#4"
M..J@P`!(,P)`*V```$@U`9CJH,``2#,!H"M@``!(-0$8ZJ#``$@S`2`K8```
M2#4%*.J@P`!(,P4P*V```$@U!1CJH,``2#,%("M@``!(-04(ZJ#``$@S!1`K
M8```2#4"B.J@P`!(,P*0*V```$@U!#CJH,``2#,$0"M@``!(-0,(ZJ#``$@S
M`Q`K8```2#4!J.J@P`!(,P&P*V```$@U`OCJH,``2#,#`"M@``!(-0%8ZJ#`
M`$@S`6`K8```2#4`V.J@P`!(,P#@*V```$@U`8CJH,``2#,!D"M@``!(-0)H
MZJ#``$@S`G`K8```2#4$".J@P`!(,P00*V```$@U`4CJH,``2#,!4"M@``!(
M-0"8ZJ#``$@S`*`K8```2#4#N.J@P`!(,P/`#\`2F6O"/]DWW@"`#]X2F6O3
M/\%KUS^1(TL@`$M:"H`BZR``2O<*F"++(`!*U@J0:]8_F6O>/XDC;P``-WL.
MZ.A?%W4(``)`!`````@``D```%=D:\(_V2M@``!`/`8P;\8`@`@!`D9KQ3^)
M:\0_D8^`(+!KPS^9*V````@!`E-(/`8X*W___S0E#@@K?___-"$.$`BA!`'0
M(1^B-",__X.#H$`V9`8X-YP``@R<$H`,O""6Z^(-U`@?`D(,@!"<BX._S3><
M``(T'``"8-P&,$O"/UE+Q3^)2\0_D4O#/YGH0,``3\8_@6O"/]DWW@"`2\(_
M6>A`P``WWC^!:\(_V2M___\WW@"`2#P.&(>`(#`T.@X8(XL@`$N6"JB&P"`8
M2\(_6>OB#/0('P)"2\(_6>A`P``WWC^!:\(_V3?>`(!+PC]9Z$#``#?>/X%K
MPC_9"`,"00@>`D-OP0"`(XL@`#><"K`,?!*0-!H``.A?&9T(``)`#X`0G`@<
M`EKH7Q0]"``"0`@<`E,CBR``-YP+``^`$)0($P):(XL@`#>9"L@(%`)8#'`0
ME^A?%N4(``)`2&(_V31^`(!/PS^!Z$#``FO"/]D(`P)!"!X"0V_!((!H>3^Q
M:'@_J31S`!@CBR``-YH+"`@3`EDT&!_^Z%\9O0@``D`,?!*0#'`0G(^`0$H,
M<!"<-Y,__S1\`!@*?`H<#X`0'-.<'_B/@"`2#'`0G#></_\,?!*0#'`0G(^`
M0+H,<!"3-'P`&`@<`EHT&0!>"!,"6.A?&LT(``)`AX`@>C0:``#H7Q?-"``"
M0`^`$)P('`):Z%\2;0@``D`,<!"4-',`&`@<`EI(>3^Q"!,"6`@4`E?H7Q>M
M"``"0.@``%HT&@``Z%\730@``D`/@!"<"!P"6NA?$>T(``)`"!P"6DAY/[%(
M>#^IZ%\3I0@``D!(8C_9-'X`@$_#/X'H0,`":\(_V0@#`D$('@)#;\$!`&AZ
M/[EH>3^Q2',_N89@(!HK8```-#P%^`^`$)R/@"`*:&``,.@``?I(?#^Y:'P`
M(.@``!)(<P`@-G,``FAS`"!(<P`@#F`0'-.<'_B'@"`J2',`(`Y@$!S3DQ_X
M-!P`>HI\/YT(``)`2',`($A\/[D+DP03:',`*"M@```T/`7X#X`0G`Q\$ICH
M``#Z2'P`*`QP$)I(>3^Y"!P"6.A?$+T(``)`CX`@JDA\`"@,<!"3"Y,*'`^`
M$!S3DQ_X-!P`>HI\('(,>!"3*V```#0\!?@/@!"<"Y,$'-.<'Z(('`)32'P_
ML0^3$H!(?``H-YP``@QP$),+DPH<:'P`,.@``$H,>!"<-YP`"`Q\$I@,>!"3
M#F`0DPQS$I`,<!"<CX`^U0@``D!H8``P2'P`,$AB/]DT?@"`3\,_@>A`P`)K
MPC_9"`,"00@>`D-OP0"`:'H_N4AZ/[DT?``0"!P"6>A?'1T(``)`2&(_V31^
M`(!/PS^!Z$#``FO"/]D(`P)!"!X"0V_!`0!H9`!`:'H_N6AY/[%(83^Q#"`0
M'-.3'_@T'`!ZBGP@$DAS/[$V<P`":',_L4AZ/['H7Q#-"``"0`Q\$I`T?``8
M2'H_N0@<`EGH7QP]"``"0&A\`#!(=``PAH`@TDAZ`##H7Q!M"``"0`@<`E,,
M<!"<BGRC0DAA/[$,(!`<TYP?^$AS`#`.?!(`2'0`,`Z`$!S3G!_XDYP@`#0<
M``+3G!OX2&$`,#0A``)H80`P2',_L39S``)H<S^QCX`_;0@``D!H8``XZ``%
MNBM@```T/`7X#X`0G&A\`"!H8``HZ```*DAT`"`VE``(:'0`($A\`"@WG``"
M:'P`*$AA`"`,(!"<CX`_M0@``D`K8```-#P&0`^`$)R'@""R*V```#0\!?@/
M@!"32'0`*#:<``37G`A""!,"6@@<`EGH7Q"="``"0`@<`E,K8```"`$"7#><
M!?@/DQ*`*V````@!`EPWG`7X#X`0G(^`(0HT$S__:',`..@`!&(K8```-#,&
M0#0<``(.?!*`2'0`*#:<``37G`A""!P"6NA?$*4(``)`:'P`($A\`""/@"`2
M-`$__VAA`#CH``/B*V```#0\!?@/@!"32'P`*-><"$)(>@`@"!,"60@<`ECH
M7P]%"``"0"M@```(`0)<-YP%^$AS`"`/DQ*`*V```#0\!?@/@!"32'P`*#><
M``+7G`A""Y,*'`^`$H!(?``H#'P2F$AT/[EH=``PZ```$DA\`#`WG``":'P`
M,$AA`#`,(!`<TYP?^(>`("I(<P`P#F`0'-.3'_@T'`!ZBGP_G0@``D`K8```
M-#P%^`^`$),,>!"<UYP(0@N3"@1(<P`P2'P_N0N3!!P('`)3#'`0G`N3"APW
MG``$"!P"6NA?#JT(``)`#)P2@`R`$)R/@"`2-!0__VAT`#CH``'J*V```#0\
M!?@/@!"3#'@0G-><"$(+DPH<#X`0G&A\`##H```22'P`,#><``)H?``P2'P_
MN0^`$!S3G!_X2&$`,`P\$@!(<P`P#F`0'-.<'_B3G"``-!P``M.3&_A(?#^Y
M-YP``FA\/[DT'``""Y,"G-.<&_B/@"`J2'0`,`Z`$!S3DQ_X-!P`>HI\/RT(
M``)`-!P`>DAA`#`,/!(`2',`,#9S``)H<P`P2'0_L0Z`$!S3G!_X2&$`,`P\
M$@!(<P`P#F`0'-.<'_B3G"``-!P``M.<&_A(=``P-I0``FAT`#!(83^Q-"$`
M`FAA/[&/@#]M"``"0&A@`#A(?``X2&(_V4AD`$`T?@"`3\,_@>A`P`)KPC_9
M"`,"00@>`D-OP0"`:'H_N>@``)(K8```-#P%^`^`$),,<!"<UYP(0@N3"A,,
M<Q*8#'@0DS9\``@/@!"<#'@0DPY\$H`,>!"3#F`0G(>`(!H,>!"<-YP`"`Q\
M$ICH'Q^?2'H_N31\`!`('`)9Z%\4;0@``D"/@#\U"``"0$AB/]DT?@"`3\,_
M@>A`P`)KPC_9"`,"00@>`D-OP3^`-]X!@`Q@$ICH7P>]"``"0`@<`E,T?``@
M"!P"6B.+(``WF0LX"!,"6".+(``WEPM0Z%\([0@``D`,?!*0#'`0G(>`8"(B
M8@``-G,`*0AS"A,.8!*`Z``!6C1\`"`T<R`B"!P"6@@3`EDT&"``Z%\+-0@`
M`D`,?!*0#'`0G(>`8"(C@@``-YP`*0A\"AP/@!*`Z```X@QP$)PWG``""!P"
M6NA?"<T(``)`#'P2F`QX$)R/@"`B(F(``#9S`"D(<PH3#F`2@.@``'H,<!"3
M-'P@(@QX$)H('`)9"!,"6.A?"K4(``)`#'`0DPQX$)P*?`H<#X`2``QX$),C
M@@``-YP`*0A\"AP/DQ*`(F(``#9S`"D(<PH3#F`0G$AB/]DT?@"`3\,_@>A`
MP`)KPC_9"`,"00@>`D-OP0"`Z%\=90@``D!(8C_9-'X`@$_#/X'H0,`":\(_
MV0@#`D$('@)#;\$A`&AZ/[EH>3^Q(XL@`#>:"UCH7Q/%"``"0`Q\$I`K8```
M"`$"7#><`!`/@!"<2'H_N0@<`EGH7P:E"``"0(>`(#HCBR``-YH+<$AY/[GH
M7Q.]"``"0$A\/[EH?"`PZ``$XDAZ/[GH7P3E"``"0&A\`"`K8```"`$"7#><
M`!@/@!"<2'H_L0@<`EGH7P?="``"0&A\`"CH``0B2'P`*`^`$!S3G!_XCX`@
M$B.+(``WG`N0:'P`*`QP$)R'@"!J#'`0FDAY`"CH7P/E"``"0(^`($(K8```
M-#P`&`^`$)PT&@``"!P"6>A?!R4(``)`:'P`*.@``VI(>@`HZ%\#O0@``D`,
M?!*8Z```,@QX$)PWG#__#'P2F`QX$)-(?``H"GP*'`^`$@`,>!"<-Y,__TA\
M`"@*?`H<#X`0'-.3'_@K8```-#P`$`^`$)P/@!`<TYP?^()\/V4(``)`#'@0
MG#>3``)(?``@"Y,*$S0<'_Z*?$`Z(XL@`#>:"W!(>3^YZ%\170@``D!(?#^Y
M:'P@,.@``H(K8```-#P`$`^`$)0T<P`P2'P_N6O</YD($P):(XL@`#>9"YA(
M>``H"!0"5^A?`Q4(``)`-!H``.A?!)T(``)`#X`0G`@<`EKH7Q\Y"``"0`@<
M`EKH7P.%"``"0`@<`E,T?``P"!P"6@@3`EGH0A9X"``"0(^`(0(T&@``Z%\$
M%0@``D`/@!"<"!P"6NA?'K$(``)`"!P"6NA?`OT(``)`2Y,`(".'(``+DP(3
M(X0``(I\((HT?``P"!P"6C09``+H7Q^)"``"0(^`(%HT<P`P(XL@`#>:"W`(
M$P)9Z%\/?0@``D`T?``P"!P"6NA?'Y$(``)`:'P@,.@``(HK8```-#P`&`^`
M$)PT&@``"!P"6>A?`ZT(``)`:'P`*$A\`"B/@#O%"``"0".+(``WF@MP2'D_
MN>A?#LT(``)`2&$_N6AA(#!(?"`P2&(_V31^`(!/PS^!Z$#``@@#`D$('@)#
M;\$`@&AZ/[E(?#^Y#'P2F$A\/[D,?!*0Z```<@QP$)P/@!`<TY,?^"M@```T
M/``0#X`0G`^`$!S3G!_XBGP@$@QP$)PWG``"#'P2F`QP$)PWG``"#'P2D`QP
M$)P/@!`<TYP?^(^`/V4(``)`#'@0G#1^`(!/PS^!Z$#``FO"/]D(`P)!"!X"
M0V_!`(!H>C^Y2'P_N8>`(!I(?#^Y#X`0'-.<'_B/@"`J(XL@`#>:"Y#H7QU)
M"``"0`Q\$ICH``-*2'H_N>A?'D$(``)`-Y,__TA\/[D*?`H<#'P2D.@``!(,
M<!"!-"$__PQA$I!(?#^Y#'`0DXI\@&H,<!"!#"`0'-.3'_@K8```-#P`$`^`
M$)P/@!`<TYP?^()\/X4(``)`Z```$@QP$),V<S__#',2D$A\/[D,<!"!B#R`
M2@QP$),.8!`<TY,?^"M@```T/``0#X`0G`^`$!S3G!_XBGP_A0@``D!(?#^Y
M#'`0@8@\(+(,<!"3#F`0'-.3'_@K8```-#P`$`^`$)P/@!`<TYP?^(I\("HC
MBR``-YH+D.A?&W$(``)`#'P2F.@``7(K8```-#P`$`^`$)P('`):Z%\;,0@`
M`D`,?!*8Z``!,@QP$)PWG#__#'P2D$A\/[D,<!"!B#R`2@QP$),.8!`<TY,?
M^"M@```T/``0#X`0G`^`$!S3G!_X@GP_A0@``D`,<!"32'P_N0N3!!PWG``$
M"!P"4S0<(`"*?(`*#&`2F.@``&H,<!"32'P_N0N3!!PWG``"*V```#0Z!DA(
M>3^Y"!P"6.A?&>D(``)`*V````@!`EPWG`9(#'P2F`QX$)Q(8C_9-'X`@$_#
M/X'H0,`":\(_V0@#`D$('@)#;\$!`".+(``WG`TH-',`&#04`$0($P):"!P"
M60@4`ECH7QYY"``"0".+(``WF@NHZ%\0I0@``D`CBR``-YH+R.A?$(4(``)`
M(XL@`#>:"UCH7Q!E"``"0".+(``WF@O@Z%\010@``D`CBR``-YH+^.A?$"4(
M``)`(XL@`#>:#!#H7Q`%"``"0".+(``WF@MPZ%\/Y0@``D`CBR``-YH,*.A?
M#\4(``)`(XL@`#>:#$#H7P^E"``"0".+(``WF@Q8Z%\'=0@``D`,?!*0#'`0
MG(>`("(CBR``-YH+^`QP$)GH7P>E"``"0".+(``WF@R`Z%\'%0@``D`,?!*0
M#'`0G(>`("(CBR``-YH,J`QP$)GH7P=%"``"0".+(``WF@S`Z%\&M0@``D`,
M?!*0#'`0G(>`("HCBR``-YH+6`QP$)GH7P;E"``"0.@``.HCBR``-YH,X.A?
M!DT(``)`#'P2D`QP$)R'@"`J(XL@`#>:"^`,<!"9Z%\&?0@``D#H``""-'P`
M&#><`"(,?!*0#'`0FB.+(``WF0T(-!@`%.A?%4$(``)`CX`@,@QP$)PWDP`4
M(XL@`#>:"^`($P)9Z%\%[0@``D`CBR``-YH+J".+(``WF0T@Z%\%O0@``D!(
M8C_9-'X`@$_#/X'H0,`":\(_V0@#`D$('@)#;\$`@"M@```T/``@#X`0G(^?
M(+HCBR``-YH+X.A?!,T(``)`#'P2D`QP$)R'@"!:#'`0G`^`$!S3G!_XAX`@
M.@QP$)P/@!`<TY,?^#0<`&""?"`2-!,``@QS$ICH```"#&`2F"M@```T/``@
M#'@0DP^3$H`K8```-#P`(`^`$)Q(8C_9-'X`@$_#/X'H0,`""`,"00@>`D-O
MP0.`:'H_N4A\/[DWG``X:'P`2&A@`%#H``!Z2'P`2`^`$)QH?`!`2'P`2#><
M``AH?`!(2'P`4-9\"$(T?``0"GP*'#>3`$A(?`!`#GP2@$A\`%`WG``":'P`
M4$A\`%"/GE]M"``"0#0<`"!H?`!0Z``!HDAU`%!(?`!0-YP_^]9\"$(T?``0
M"GP*'#><`$@/@!"42'P`4#></_'6?`A"-'P`$`I\"APWG`!(#X`0G`N4`I1(
M?`!0-YP_Y=9\"$(T?``0"GP*'#><`$@/@!"<"Y0"E$A\`%`WG#_AUGP(0C1\
M`!`*?`H<-YP`2`^`$)P+E`*4UG4(0C1\`!`*?`H<-YP`2`^4$H!(=0!02'P`
M4-9\"$(T?``0"GP*'#><`$@/@!"<TYP(%-9U"$(T?``0"GP*'#><`$@/E!*`
M2'P`4#><``)H?`!02',`4#0<`)Z*?%X]"``"0$A\/[D/@!"<:'P`.$A\/[D/
MB!"<:'P`,$A\/[D/D!"<:'P`*$A\/[D/F!"<:'P`($A\/[E+G``@#'P2F#1\
M`%@,?!*02'P`.-.<")5(<P`P2'P`*`N3`A1(?``P"X`)DTA\`"`+DP(<"Y0"
M7`N5"A,,>!"<"Y,*$PQP$)P/@!"<"Y,*$R.4"U`WG#,S"Y,*'&A\`$`,<!"<
M-YP`"`Q\$I!(?``PTYP+O&A\`#!(?`!`TYP(E4AS`#A(?``P"Y,"%$A\`#@+
M@`F32'P`*`N3`AP+E`)<"Y4*$TA\`"`+DPH3#'`0G`^`$)P+DPH3(Y0+4#><
M,S,+DPH<#'P2F`QP$)PWG``(#'P2D$A\`#C3G`N\:'P`.`QX$)S3G`B52',`
M0$A\`#@+DP(42'P`0`N`"9-(?``P"Y,"'`N4`EP+E0H32'P`*`N3"A,,<!"<
M#X`0G`N3"A,CE`M0-YPS,PN3"AQH?``@#'`0G#><``@,?!*02'P`0-.<"[QH
M?`!`2'P`(-.<")4,>!"32'P`0`N3`A0,>!"<"X`)DTA\`#@+DP(<"Y0"7`N5
M"A-(?``P"Y,*$PQP$)P/@!"<"Y,*$R.4"U`WG#,S"Y,*'&A\`"@,<!"<-YP`
M"`Q\$I`,>!"<TYP+O`Q\$IA(?``HTYP(E4AS`"`,>!"<"Y,"%$A\`"`+@`F3
M2'P`0`N3`AP+E`)<"Y4*$TA\`#@+DPH3#'`0G`^`$)P+DPH3(Y0+4#><,S,+
MDPH<:'P`,`QP$)PWG``(#'P2D$A\`"#3G`N\:'P`($A\`##3G`B52',`*$A\
M`"`+DP(42'P`*`N`"9,,>!"<"Y,"'`N4`EP+E0H32'P`0`N3"A,,<!"<#X`0
MG`N3"A,CE`M0-YPS,PN3"AQH?``X#'`0G#><``@,?!*02'P`*-.<"[QH?``H
M2'P`.-.<")5(<P`P2'P`*`N3`A1(?``P"X`)DTA\`"`+DP(<"Y0"7`N5"A,,
M>!"<"Y,*$PQP$)P/@!"<"Y,*$R.4"U`WG#,S"Y,*'&A\`$`,<!"<-YP`"`Q\
M$I!(?``PTYP+O&A\`#!(?`!`TYP(E4AS`#A(?``P"Y,"%$A\`#@+@`F32'P`
M*`N3`AP+E`)<"Y4*$TA\`"`+DPH3#'`0G`^`$)P+DPH3(Y0+4#><,S,+DPH<
M#'P2F`QP$)PWG``(#'P2D$A\`#C3G`N\:'P`.`QX$)S3G`B52',`0$A\`#@+
MDP(42'P`0`N`"9-(?``P"Y,"'`N4`EP+E0H32'P`*`N3"A,,<!"<#X`0G`N3
M"A,CE`M0-YPS,PN3"AQH?``@#'`0G#><``@,?!*02'P`0-.<"[QH?`!`2'P`
M(-.<")4,>!"32'P`0`N3`A0,>!"<"X`)DTA\`#@+DP(<"Y0"7`N5"A-(?``P
M"Y,*$PQP$)P/@!"<"Y,*$R.4"U`WG#,S"Y,*'&A\`"@,<!"<-YP`"`Q\$I`,
M>!"<TYP+O`Q\$IA(?``HTYP(E4AS`"`,>!"<"Y,"%$A\`"`+@`F32'P`0`N3
M`AP+E`)<"Y4*$TA\`#@+DPH3#'`0G`^`$)P+DPH3(Y0+4#><,S,+DPH<:'P`
M,`QP$)PWG``(#'P2D$A\`"#3G`N\:'P`($A\`##3G`B52',`*$A\`"`+DP(4
M2'P`*`N`"9,,>!"<"Y,"'`N4`EP+E0H32'P`0`N3"A,,<!"<#X`0G`N3"A,C
ME`M0-YPS,PN3"AQH?``X#'`0G#><``@,?!*02'P`*-.<"[QH?``H2'P`.-.<
M")5(<P`P2'P`*`N3`A1(?``P"X`)DTA\`"`+DP(<"Y0"7`N5"A,,>!"<"Y,*
M$PQP$)P/@!"<"Y,*$R.4"U`WG#,S"Y,*'&A\`$`,<!"<-YP`"`Q\$I!(?``P
MTYP+O&A\`#!(?`!`TYP(E4AS`#A(?``P"Y,"%$A\`#@+@`F32'P`*`N3`AP+
ME`)<"Y4*$TA\`"`+DPH3#'`0G`^`$)P+DPH3(Y0+4#><,S,+DPH<#'P2F`QP
M$)PWG``(#'P2D$A\`#C3G`N\:'P`.`QX$)S3G`B52',`0$A\`#@+DP(42'P`
M0`N`"9-(?``P"Y,"'`N4`EP+E0H32'P`*`N3"A,,<!"<#X`0G`N3"A,CE`M0
M-YPS,PN3"AQH?``@#'`0G#><``@,?!*02'P`0-.<"[QH?`!`2'P`(-.<")4,
M>!"32'P`0`N3`A0,>!"<"X`)DTA\`#@+DP(<"Y0"7`N5"A-(?``P"Y,*$PQP
M$)P/@!"<"Y,*$R.4"U`WG#,S"Y,*'&A\`"@,<!"<-YP`"`Q\$I`,>!"<TYP+
MO`Q\$IA(?``HTYP(E4AS`"`,>!"<"Y,"%$A\`"`+@`F32'P`0`N3`AP+E`)<
M"Y4*$TA\`#@+DPH3#'`0G`^`$)P+DPH3(Y0+4#><,S,+DPH<:'P`,`QP$)PW
MG``(#'P2D$A\`"#3G`N\:'P`($A\`##3G`B52',`*$A\`"`+DP(42'P`*`N`
M"9,,>!"<"Y,"'`N4`EP+E0H32'P`0`N3"A,,<!"<#X`0G`N3"A,CE`M0-YPS
M,PN3"AQH?``X#'`0G#><``@,?!*02'P`*-.<"[QH?``H2'P`.-.<")5(<P`P
M2'P`*`N3`A1(?``P"X`)DTA\`"`+DP(<"Y0"7`N5"A,,>!"<"Y,*$PQP$)P/
M@!"<"Y,*$R.4"U`WG#,S"Y,*'&A\`$`,<!"<-YP`"`Q\$I!(?``PTYP+O&A\
M`#!(?`!`TYP(E4AS`#A(?``P"Y,"%$A\`#@+@`F32'P`*`N3`AP+E`)<"Y4*
M$TA\`"`+DPH3#'`0G`^`$)P+DPH3(Y0+4#><,S,+DPH<#'P2F`QP$)PWG``(
M#'P2D$A\`#C3G`N\:'P`.`QX$)S3G`B42',`0$A\`#@+DP*32'P`,`N3`IP+
ME`H32'P`*`N3"A,,<!"<#X`0G`N3"A,CD(W:-YP70PN3"AQH?``@#'`0G#><
M``@,?!*02'P`0-.<"[QH?`!`2'P`(-.<")0,>!"32'P`0`N3`I-(?``X"Y,"
MG`N4"A-(?``P"Y,*$PQP$)P/@!"<"Y,*$R.0C=HWG!=#"Y,*'&A\`"@,<!"<
M-YP`"`Q\$I`,>!"<TYP+O`Q\$IA(?``HTYP(E$AS`"`,>!"<"Y,"DTA\`$`+
MDP*<"Y0*$TA\`#@+DPH3#'`0G`^`$)P+DPH3(Y"-VC><%T,+DPH<:'P`,`QP
M$)PWG``(#'P2D$A\`"#3G`N\:'P`($A\`##3G`B42',`*$A\`"`+DP*3#'@0
MG`N3`IP+E`H32'P`0`N3"A,,<!"<#X`0G`N3"A,CD(W:-YP70PN3"AQH?``X
M#'`0G#><``@,?!*02'P`*-.<"[QH?``H2'P`.-.<")1(<P`P2'P`*`N3`I-(
M?``@"Y,"G`N4"A,,>!"<"Y,*$PQP$)P/@!"<"Y,*$R.0C=HWG!=#"Y,*'&A\
M`$`,<!"<-YP`"`Q\$I!(?``PTYP+O&A\`#!(?`!`TYP(E$AS`#A(?``P"Y,"
MDTA\`"@+DP*<"Y0*$TA\`"`+DPH3#'`0G`^`$)P+DPH3(Y"-VC><%T,+DPH<
M#'P2F`QP$)PWG``(#'P2D$A\`#C3G`N\:'P`.`QX$)S3G`B42',`0$A\`#@+
MDP*32'P`,`N3`IP+E`H32'P`*`N3"A,,<!"<#X`0G`N3"A,CD(W:-YP70PN3
M"AQH?``@#'`0G#><``@,?!*02'P`0-.<"[QH?`!`2'P`(-.<")0,>!"32'P`
M0`N3`I-(?``X"Y,"G`N4"A-(?``P"Y,*$PQP$)P/@!"<"Y,*$R.0C=HWG!=#
M"Y,*'&A\`"@,<!"<-YP`"`Q\$I`,>!"<TYP+O`Q\$IA(?``HTYP(E$AS`"`,
M>!"<"Y,"DTA\`$`+DP*<"Y0*$TA\`#@+DPH3#'`0G`^`$)P+DPH3(Y"-VC><
M%T,+DPH<:'P`,`QP$)PWG``(#'P2D$A\`"#3G`N\:'P`($A\`##3G`B42',`
M*$A\`"`+DP*3#'@0G`N3`IP+E`H32'P`0`N3"A,,<!"<#X`0G`N3"A,CD(W:
M-YP70PN3"AQH?``X#'`0G#><``@,?!*02'P`*-.<"[QH?``H2'P`.-.<")1(
M<P`P2'P`*`N3`I-(?``@"Y,"G`N4"A,,>!"<"Y,*$PQP$)P/@!"<"Y,*$R.0
MC=HWG!=#"Y,*'&A\`$`,<!"<-YP`"`Q\$I!(?``PTYP+O&A\`#!(?`!`TYP(
ME$AS`#A(?``P"Y,"DTA\`"@+DP*<"Y0*$TA\`"`+DPH3#'`0G`^`$)P+DPH3
M(Y"-VC><%T,+DPH<#'P2F`QP$)PWG``(#'P2D$A\`#C3G`N\:'P`.`QX$)S3
MG`B42',`0$A\`#@+DP*32'P`,`N3`IP+E`H32'P`*`N3"A,,<!"<#X`0G`N3
M"A,CD(W:-YP70PN3"AQH?``@#'`0G#><``@,?!*02'P`0-.<"[QH?`!`2'P`
M(-.<")0,>!"32'P`0`N3`I-(?``X"Y,"G`N4"A-(?``P"Y,*$PQP$)P/@!"<
M"Y,*$R.0C=HWG!=#"Y,*'&A\`"@,<!"<-YP`"`Q\$I`,>!"<TYP+O`Q\$IA(
M?``HTYP(E$AS`"`,>!"<"Y,"DTA\`$`+DP*<"Y0*$TA\`#@+DPH3#'`0G`^`
M$)P+DPH3(Y"-VC><%T,+DPH<:'P`,`QP$)PWG``(#'P2D$A\`"#3G`N\:'P`
M($A\`##3G`B42',`*$A\`"`+DP*3#'@0G`N3`IP+E`H32'P`0`N3"A,,<!"<
M#X`0G`N3"A,CD(W:-YP70PN3"AQH?``X#'`0G#><``@,?!*02'P`*-.<"[QH
M?``H2'P`.-.<")1(<P`P2'P`*`N3`I-(?``@"Y,"G`N4"A,,>!"<"Y,*$PQP
M$)P/@!"<"Y,*$R.0C=HWG!=#"Y,*'&A\`$`,<!"<-YP`"`Q\$I!(?``PTYP+
MO&A\`#!(?`!`TYP(E$AS`#A(?``P"Y,"DTA\`"@+DP*<"Y0*$TA\`"`+DPH3
M#'`0G`^`$)P+DPH3(Y"-VC><%T,+DPH<#'P2F`QP$)PWG``(#'P2D$A\`#C3
MG`N\:'P`.`QX$)S3G`B42',`0$A\`#@+DP*32'P`,`N3`IP+E`H32'P`*`N3
M"A,,<!"<#X`0G`N3"A,CD(W:-YP70PN3"AQH?``@#'`0G#><``@,?!*02'P`
M0-.<"[QH?`!`2'P`(-.<")0,>!"32'P`0`N3`I-(?``X"Y,"G`N4"A-(?``P
M"Y,*$PQP$)P/@!"<"Y,*$R.0C=HWG!=#"Y,*'&A\`"@,<!"<-YP`"`Q\$I`,
M>!"<TYP+O`Q\$IA(?``HTYP(E0QX$)-(?`!`"Y,"4TA\`"`+DP(4#'@0DTA\
M`$`+DP(<"Y0"7`N5"A-(?``X"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*
M'&A\`#`,<!"<-YP`"`Q\$I!(?``@TYP+O&A\`"!(?``PTYP(E4AS`"`,>!"<
M"Y,"4TA\`"@+DP(42',`(`QX$)P+DP(<"Y0"7`N5"A-(?`!`"Y,*$PQP$)P/
M@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`#@,<!"<-YP`"`Q\$I!(?``HTYP+O&A\
M`"A(?``XTYP(E4AS`"A(?``@"Y,"4TA\`#`+DP(42',`*$A\`"`+DP(<"Y0"
M7`N5"A,,>!"<"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`$`,<!"<
M-YP`"`Q\$I!(?``PTYP+O&A\`#!(?`!`TYP(E4AS`#!(?``H"Y,"4TA\`#@+
MDP(42',`,$A\`"@+DP(<"Y0"7`N5"A-(?``@"Y,*$PQP$)P/@!"<"Y,*$R.>
M@>,WG#FY"Y,*'`Q\$I@,<!"<-YP`"`Q\$I!(?``XTYP+O&A\`#@,>!"<TYP(
ME4AS`#A(?``P"Y,"4TA\`$`+DP(42',`.$A\`#`+DP(<"Y0"7`N5"A-(?``H
M"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`"`,<!"<-YP`"`Q\$I!(
M?`!`TYP+O&A\`$!(?``@TYP(E4AS`$!(?``X"Y,"4PQX$)P+DP(42',`0$A\
M`#@+DP(<"Y0"7`N5"A-(?``P"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*
M'&A\`"@,<!"<-YP`"`Q\$I`,>!"<TYP+O`Q\$IA(?``HTYP(E0QX$)-(?`!`
M"Y,"4TA\`"`+DP(4#'@0DTA\`$`+DP(<"Y0"7`N5"A-(?``X"Y,*$PQP$)P/
M@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`#`,<!"<-YP`"`Q\$I!(?``@TYP+O&A\
M`"!(?``PTYP(E4AS`"`,>!"<"Y,"4TA\`"@+DP(42',`(`QX$)P+DP(<"Y0"
M7`N5"A-(?`!`"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`#@,<!"<
M-YP`"`Q\$I!(?``HTYP+O&A\`"A(?``XTYP(E4AS`"A(?``@"Y,"4TA\`#`+
MDP(42',`*$A\`"`+DP(<"Y0"7`N5"A,,>!"<"Y,*$PQP$)P/@!"<"Y,*$R.>
M@>,WG#FY"Y,*'&A\`$`,<!"<-YP`"`Q\$I!(?``PTYP+O&A\`#!(?`!`TYP(
ME4AS`#!(?``H"Y,"4TA\`#@+DP(42',`,$A\`"@+DP(<"Y0"7`N5"A-(?``@
M"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*'`Q\$I@,<!"<-YP`"`Q\$I!(
M?``XTYP+O&A\`#@,>!"<TYP(E4AS`#A(?``P"Y,"4TA\`$`+DP(42',`.$A\
M`#`+DP(<"Y0"7`N5"A-(?``H"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*
M'&A\`"`,<!"<-YP`"`Q\$I!(?`!`TYP+O&A\`$!(?``@TYP(E4AS`$!(?``X
M"Y,"4PQX$)P+DP(42',`0$A\`#@+DP(<"Y0"7`N5"A-(?``P"Y,*$PQP$)P/
M@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`"@,<!"<-YP`"`Q\$I`,>!"<TYP+O`Q\
M$IA(?``HTYP(E0QX$)-(?`!`"Y,"4TA\`"`+DP(4#'@0DTA\`$`+DP(<"Y0"
M7`N5"A-(?``X"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`#`,<!"<
M-YP`"`Q\$I!(?``@TYP+O&A\`"!(?``PTYP(E4AS`"`,>!"<"Y,"4TA\`"@+
MDP(42',`(`QX$)P+DP(<"Y0"7`N5"A-(?`!`"Y,*$PQP$)P/@!"<"Y,*$R.>
M@>,WG#FY"Y,*'&A\`#@,<!"<-YP`"`Q\$I!(?``HTYP+O&A\`"A(?``XTYP(
ME4AS`"A(?``@"Y,"4TA\`#`+DP(42',`*$A\`"`+DP(<"Y0"7`N5"A,,>!"<
M"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`$`,<!"<-YP`"`Q\$I!(
M?``PTYP+O&A\`#!(?`!`TYP(E4AS`#!(?``H"Y,"4TA\`#@+DP(42',`,$A\
M`"@+DP(<"Y0"7`N5"A-(?``@"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*
M'`Q\$I@,<!"<-YP`"`Q\$I!(?``XTYP+O&A\`#@,>!"<TYP(E4AS`#A(?``P
M"Y,"4TA\`$`+DP(42',`.$A\`#`+DP(<"Y0"7`N5"A-(?``H"Y,*$PQP$)P/
M@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`"`,<!"<-YP`"`Q\$I!(?`!`TYP+O&A\
M`$!(?``@TYP(E4AS`$!(?``X"Y,"4PQX$)P+DP(42',`0$A\`#@+DP(<"Y0"
M7`N5"A-(?``P"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`"@,<!"<
M-YP`"`Q\$I`,>!"<TYP+O`Q\$IA(?``HTYP(E0QX$)-(?`!`"Y,"4TA\`"`+
MDP(4#'@0DTA\`$`+DP(<"Y0"7`N5"A-(?``X"Y,*$PQP$)P/@!"<"Y,*$R.>
M@>,WG#FY"Y,*'&A\`#`,<!"<-YP`"`Q\$I!(?``@TYP+O&A\`"!(?``PTYP(
ME4AS`"`,>!"<"Y,"4TA\`"@+DP(42',`(`QX$)P+DP(<"Y0"7`N5"A-(?`!`
M"Y,*$PQP$)P/@!"<"Y,*$R.>@>,WG#FY"Y,*'&A\`#@,<!"<-YP`"`Q\$I!(
M?``HTYP+O&A\`"A(?``XTYP(E$AS`#!(?``H"Y,"DTA\`"`+DP*<"Y0*$PQX
M$)P+DPH3#'`0G`^`$)P+DPH3(Y8)33><`ZP+DPH<:'P`0`QP$)PWG``(#'P2
MD$A\`##3G`N\:'P`,$A\`$#3G`B42',`.$A\`#`+DP*32'P`*`N3`IP+E`H3
M2'P`(`N3"A,,<!"<#X`0G`N3"A,CE@E--YP#K`N3"AP,?!*8#'`0G#><``@,
M?!*02'P`.-.<"[QH?``X#'@0G-.<")1(<P!`2'P`.`N3`I-(?``P"Y,"G`N4
M"A-(?``H"Y,*$PQP$)P/@!"<"Y,*$R.6"4TWG`.L"Y,*'&A\`"`,<!"<-YP`
M"`Q\$I!(?`!`TYP+O&A\`$!(?``@TYP(E`QX$)-(?`!`"Y,"DTA\`#@+DP*<
M"Y0*$TA\`#`+DPH3#'`0G`^`$)P+DPH3(Y8)33><`ZP+DPH<:'P`*`QP$)PW
MG``(#'P2D`QX$)S3G`N\#'P2F$A\`"C3G`B42',`(`QX$)P+DP*32'P`0`N3
M`IP+E`H32'P`.`N3"A,,<!"<#X`0G`N3"A,CE@E--YP#K`N3"AQH?``P#'`0
MG#><``@,?!*02'P`(-.<"[QH?``@2'P`,-.<")1(<P`H2'P`(`N3`I,,>!"<
M"Y,"G`N4"A-(?`!`"Y,*$PQP$)P/@!"<"Y,*$R.6"4TWG`.L"Y,*'&A\`#@,
M<!"<-YP`"`Q\$I!(?``HTYP+O&A\`"A(?``XTYP(E$AS`#!(?``H"Y,"DTA\
M`"`+DP*<"Y0*$PQX$)P+DPH3#'`0G`^`$)P+DPH3(Y8)33><`ZP+DPH<:'P`
M0`QP$)PWG``(#'P2D$A\`##3G`N\:'P`,$A\`$#3G`B42',`.$A\`#`+DP*3
M2'P`*`N3`IP+E`H32'P`(`N3"A,,<!"<#X`0G`N3"A,CE@E--YP#K`N3"AP,
M?!*8#'`0G#><``@,?!*02'P`.-.<"[QH?``X#'@0G-.<")1(<P!`2'P`.`N3
M`I-(?``P"Y,"G`N4"A-(?``H"Y,*$PQP$)P/@!"<"Y,*$R.6"4TWG`.L"Y,*
M'&A\`"`,<!"<-YP`"`Q\$I!(?`!`TYP+O&A\`$!(?``@TYP(E`QX$)-(?`!`
M"Y,"DTA\`#@+DP*<"Y0*$TA\`#`+DPH3#'`0G`^`$)P+DPH3(Y8)33><`ZP+
MDPH<:'P`*`QP$)PWG``(#'P2D`QX$)S3G`N\#'P2F$A\`"C3G`B42',`(`QX
M$)P+DP*32'P`0`N3`IP+E`H32'P`.`N3"A,,<!"<#X`0G`N3"A,CE@E--YP#
MK`N3"AQH?``P#'`0G#><``@,?!*02'P`(-.<"[QH?``@2'P`,-.<")1(<P`H
M2'P`(`N3`I,,>!"<"Y,"G`N4"A-(?`!`"Y,*$PQP$)P/@!"<"Y,*$R.6"4TW
MG`.L"Y,*'&A\`#@,<!"<-YP`"`Q\$I!(?``HTYP+O&A\`"A(?``XTYP(E$AS
M`#!(?``H"Y,"DTA\`"`+DP*<"Y0*$PQX$)P+DPH3#'`0G`^`$)P+DPH3(Y8)
M33><`ZP+DPH<:'P`0`QP$)PWG``(#'P2D$A\`##3G`N\:'P`,$A\`$#3G`B4
M2',`.$A\`#`+DP*32'P`*`N3`IP+E`H32'P`(`N3"A,,<!"<#X`0G`N3"A,C
ME@E--YP#K`N3"AP,?!*8#'`0G#><``@,?!*02'P`.-.<"[QH?``X#'@0G-.<
M")1(<P!`2'P`.`N3`I-(?``P"Y,"G`N4"A-(?``H"Y,*$PQP$)P/@!"<"Y,*
M$R.6"4TWG`.L"Y,*'&A\`"`,<!"<-YP`"`Q\$I!(?`!`TYP+O&A\`$!(?``@
MTYP(E`QX$)-(?`!`"Y,"DTA\`#@+DP*<"Y0*$TA\`#`+DPH3#'`0G`^`$)P+
MDPH3(Y8)33><`ZP+DPH<:'P`*`QP$)PWG``(#'P2D`QX$)S3G`N\#'P2F$A\
M`"C3G`B42',`(`QX$)P+DP*32'P`0`N3`IP+E`H32'P`.`N3"A,,<!"<#X`0
MG`N3"A,CE@E--YP#K`N3"AQH?``P#'`0G#><``@,?!*02'P`(-.<"[QH?``@
M2'P`,-.<")1(<P`H2'P`(`N3`I,,>!"<"Y,"G`N4"A-(?`!`"Y,*$PQP$)P/
M@!"<"Y,*$R.6"4TWG`.L"Y,*'&A\`#@,<!"<-YP`"`Q\$I!(?``HTYP+O&A\
M`"A(?``XTYP(E$AS`#!(?``H"Y,"DTA\`"`+DP*<"Y0*$PQX$)P+DPH3#'`0
MG`^`$)P+DPH3(Y8)33><`ZP+DPH<:'P`0`QP$)PWG``(#'P2D$A\`##3G`N\
M:'P`,$A\`$#3G`B42',`.$A\`#`+DP*32'P`*`N3`IP+E`H32'P`(`N3"A,,
M<!"<#X`0G`N3"A,CE@E--YP#K`N3"AP,?!*8#'`0G#><``@,?!*02'P`.-.<
M"[QH?``X2'P_N0^`$),,>!"<"Y,*$TA\/[D/DQ*`2'P_N0^($)-(?`!`"Y,*
M$TA\/[D/DQ*(2'P_N0^0$)-(?``X"Y,*$TA\/[D/DQ*02'P_N0^8$)-(?``P
M"Y,*$TA\/[D/DQ*82'P_N4N3`"!(?``H"Y,*$TA\/[EKDP`@-'X`@$_#/X'H
M0,`""`,"00@>`D-OP0"`:'H_N4AS/[DCBDSH-YP&`PY\$H!(<S^Y(X[-^3><
M%Q,.?!*(2',_N2.6@Q<WG#G\#GP2D$AS/[DCD@(&-YPH[`Y\$IA(<S^Y(Y@(
M>S><`^%J?``@2'P_N6N``"A(?#^Y:X``,$A\/[EK@`"X-'X`@$_#/X'H0,`"
M:\(_V0@#`D$('@)#;\$`@&AZ/[EH>3^Q:'@_J4A\/[E+DP`H2'P_J=><"&,+
MDPH<#'P2D$A\/[E+DP`H#'`0G(I\@")(?#^Y2YP`,#>3``)(?#^Y:Y,`,$AS
M/[D,<!"<:GP`*$A\/[E+DP`P2'P_J=.<&%T+DPH32'P_N6N3`#!(?#^Y2YP`
MN(>`(<I(?#^Y2YP`N)><`(`,?!*8#'@0DTA\/ZF*?$`*2'P_J0Q\$IA(?#^Y
M-Y,`.$A\/[E+G`"X"Y,*'`QX$),('`):2'D_L0@3`ECH7A3)"``"0$AS/ZD,
M>!"<"Y,$'&A\/ZD,>!"32'P_L0I\"AQH?#^Q2'P_N4N3`+@,>!"<"Y,*$TA\
M/[EKDP"X2'P_N4N3`+@T'`"`BGPA$DAZ/[GH7AIM"``"0.@``'I(?#^Y-YP`
M.`@<`EI(>3^Q-!@`@.A>$^$(``)`2'P_L3><`(!H?#^Q2'P_J3></X%H?#^I
M2'H_N>A>&>4(``)`2',_J30<`'Z"?%]E"``"0$A\/[DWG``X2',_J0@<`EI(
M>3^Q"!,"6.A>$SD(``)`2',_N4A\/ZEJ?`"X2&(_V31^`(!/PS^!Z$#``FO"
M/]D(`P)!"!X"0V_!`(!H>C^Y:'D_L4AZ/['H7AD%"``"0$A\/[$/@!"<TYP8
M^-.3&_A(?#^Y#Y,2`$A\/[DWDP`"2'P_L0^`$)S3G!GPTYP;^`Y\$@!(?#^Y
M-Y,`!$A\/[$/@!"<TYP:Z-.<&_@.?!(`2'P_N3>3``9(?#^Q#X`0G-.<&_@.
M?!(`2'P_N3>3``A(?#^Q#X@0G-.<&/C3G!OX#GP2`$A\/[DWDP`*2'P_L0^(
M$)S3G!GPTYP;^`Y\$@!(?#^Y-Y,`#$A\/[$/B!"<TYP:Z-.<&_@.?!(`2'P_
MN3>3``Y(?#^Q#X@0G-.<&_@.?!(`2'P_N3>3`!!(?#^Q#Y`0G-.<&/C3G!OX
M#GP2`$A\/[DWDP`22'P_L0^0$)S3G!GPTYP;^`Y\$@!(?#^Y-Y,`%$A\/[$/
MD!"<TYP:Z-.<&_@.?!(`2'P_N3>3`!9(?#^Q#Y`0G-.<&_@.?!(`2'P_N3>3
M`!A(?#^Q#Y@0G-.<&/C3G!OX#GP2`$A\/[DWDP`:2'P_L0^8$)S3G!GPTYP;
M^`Y\$@!(?#^Y-Y,`'$A\/[$/F!"<TYP:Z-.<&_@.?!(`2'P_N3>3`!Y(?#^Q
M#Y@0G-.<&_@.?!(`2'P_N3>3`"!(?#^Q2YP`(-.<&/C3G!OX#GP2`$A\/[DW
MDP`B2'P_L4N<`"#3G!GPTYP;^`Y\$@!(?#^Y-Y,`)$A\/[%+G``@TYP:Z-.<
M&_@.?!(`2'P_N3>3`"9(?#^Q2YP`(-.<&_@.?!(`2&(_V31^`(!/PS^!Z$#`
M`FO"/]D(`P)!"!X"0V_!`0!H>C^Y:'D_L4A\/[%+G``H#'P2F$A\/[%+G``P
M#'P2D`QX$)S3G!N#TYP;^FA\`"!(?#^Q-Y,`.$A\`"`+DPH3-!P_`0Y\$@!(
M?``@-YP``FA\`"!(<P`@-!P`<(I\0*I(?#^Q-Y,`.$A\`"`+DPH32'P`()><
M`(`($P):-!D```@<`ECH7@81"``"0$AZ/['H7A-E"``"0$A\/[$WG``X"!P"
M6C09```T&`!PZ%X%P0@``D#H``!22'P_L3>3`#A(?``@"Y,*$TA\`""7G`!P
M"!,"6C09```('`)8Z%X%80@``D`,<!"<TYP8^-.3&_A(?#^Q8Y,`J`QP$)S3
MG!GPTY,;^$A\/[%CDP"J#'`0G-.<&NC3DQOX2'P_L6.3`*P,<!"<TY,;^$A\
M/[%CDP"N#'@0G-.<&/C3DQOX2'P_L6.3`+`,>!"<TYP9\-.3&_A(?#^Q8Y,`
ML@QX$)S3G!KHTY,;^$A\/[%CDP"T#'@0G-.3&_A(?#^Q8Y,`MDAZ/[E(>3^Q
MZ%\8-0@``D!(8C_9-'X`@$_#/X'H0,`":\(_V0@#`D$('@)#;\$!`&A@`"`,
M8!*8Z%X,D0@``D`,?!*0#'`0G(>`(#(,<!":Z%X$P0@``D`,?!*8#'@0G`^`
M$)QH?``@2'P`($AB/]DT?@"`3\,_@>A`P`)KPC_9"`,"00@>`D-OP0$`:&0`
M8&AZ/[EH8``H:&``("M\W_\T/`\8-',`,#04`#`($P):"!P"60@4`ECH7@G1
M"``"0`Q@$I`,8!*8Z``!XDAZ`"CH7A/9"``"0&A\`"!(?``@AX`@&DA\`"`/
M@!`<TYP?^(^`(")(>@`H2'D_N>A>$_$(``)`Z``!4DAZ`"!(>3^YZ%X&@0@`
M`D"/@"$J2'H_N>A>!0$(``)`"!P"1"M@```(`0)<-YP`&`^`$)P('`):Z%X$
MP0@``D`+A`H$2'H`(.A>!*$(``)`"X0*'#><``0('`):Z%X'&0@``D`,?!*0
M*V````@!`EPWG``8#X`0DTA\`"!KW#^9#'`0FB.+(``WF0N82'@_N0@3`E?H
M7@3I"``"0$AZ`"@,<!"9Z%X2D0@``D`,>!"<-YP``@Q\$I@,>!"<UGP(0C1\
M`!`*?`H<-YP`(`^`$)QH?``H2'P`*`^`$!S3G!_XCX`]O0@``D!(8C_92&0`
M8#1^`(!/PS^!Z$#``FO"/]D(`P)!"!X"0V_!/X`KPP``-#X#@"AD``!H)`(P
M:'H_N6A@`&AH8`!@:&``6"M\W_\T/`_0-',`@#04`"`($P):"!P"60@4`ECH
M7@:A"``"0"M\W_\(`0)<-YP/@#1S`*`T%``P"!,"6@@<`ED(%`)8Z%X&40@`
M`D`CBR``-YP.V&A\`-`CBR``-YP.Z&A\`-@CBR``-YP-^&A\`.`CBR``-YP/
M`&A\`%`CBR``-YP-^&A\`$AH8`!`:&``.&A@`#`,8!*0(XL@`#>:"UCH7@_1
M"``"0&A\`%A(?`!8AX`@<DA\`%@/@!`<TYP?^(>`(%)(>@!8Z%\:]0@``D!(
M>@!8Z%X`$0@``D`B9```-G,"*`AS"A,.?!*`Z``.JNA?&>T(``)`:'P`.$A\
M`#B/@"#B:&``>.@``&)(>@!@Z%X.\0@``D!H?`!82'P`6(>`(!I(>@!8Z%T?
M;0@``D!H?``X2'P`>#><``)H?`!X2'P`.(^`(%I(?`!XUGP(0C1\`!`*?`H<
M-YP`P`^`$)QH?`!@2'P`8`^`$!S3G!_XCX`_+0@``D!(?``XCX`@&B.+(``W
MG`\0:'P`..@``-I(?``X:'P`<.@``)KH7@#A"``"0`^`$)-(?`!P#X`0'-.<
M'_C7G`@A"Y,*'`^`$%S3G!OP"!P"4S0<$``+DP(<CX`@$DAS`'`T'`"^#GP2
M`$A\`'`WG``":'P`<$A\`'`/@!`<TYP?^(^`/ST(``)`:&``>.@``?)(>@!@
MZ%X,^0@``D!H?`!82'P`6(>`(:HT&@``Z%X!$0@``D`/@!"<"!P"6NA=&[4(
M``)`"!P"6NA='_T(``)`2'H`6`@<`EGH0!-$"``"0(^`(3(T&@``Z%X`F0@`
M`D`/@!"<"!P"6NA=&ST(``)`"!P"6NA='X4(``)`2Y,`(".'(``+DP(3(X(`
M`()\('(T&@``Z%X`(0@``D`/@!"<"!P"6NA=&L4(``)`"!P"6NA='PT(``)`
M2Y,`(".'(``+DP(3(X4``(I\($)(>@!8-!D`!.A=&Z4(``)`CX`@&DAZ`%CH
M71OE"``"0&A\`&A(?`!X-YP``FA\`'A(?`!HCX`@6DA\`'C6?`A"-'P`$`I\
M"APWG`"0#X`0G&A\`&!(?`!@#X`0'-.<'_B/@#V="``"0&A@`'CH``'"-!H`
M`.A='LT(``)`#X`0G`@<`EKH71EM"``"0`@<`EKH71VU"``"0$AZ`%@('`)9
MZ$`0_`@``D"/@"$R-!H``.A='E4(``)`#X`0G`@<`EKH71CU"``"0`@<`EKH
M71T]"``"0$N3`"`CAR``"Y,"$R."``""?"!R-!H``.A='=T(``)`#X`0G`@<
M`EKH71A]"``"0`@<`EKH71S%"``"0$N3`"`CAR``"Y,"$R.%``"*?"!"2'H`
M6#09``3H71E="``"0(^`(!I(>@!8Z%T9G0@``D!H?`!H2'P`>#><``)H?`!X
M2'P`:(^`(%I(?`!XUGP(0C1\`!`*?`H<-YP`<`^`$)QH?`!82'P`6`^`$!S3
MG!_XCX`]S0@``D!(>@!HZ%T:%0@``D`('`)$2'H`4.A=&?4(``)`"X0*!$AZ
M`#CH71G5"``"0`N$"@1(>@!(Z%T9M0@``D`+A`H<-YP(``Q\$I`,<!"<"!P"
M6NA='!T(``)`:'P`,"M@```(`0)<-YP`$`^`$)-(?`!0:]P_F4A\`#AKW#^1
M2'H`,".+(``WF0\@2'@`:`@3`E?H71G="``"0$AZ`#`T&0/:Z%T5_0@``D`C
MBR``-YH-P.A>!O$(``)`:'P`6$A\/[D/@!"$2'H`6.A=%VT(``)`"`0"6@@<
M`EGH7A*1"``"0&A\`$!(?`!`CX`@$DA\/[D/@!"<:'P`0.A>`3T(``)`CX`D
MJDAZ`$`T&0``Z%T;!0@``D!H?``H2'P`*(>`)'(T'``$:]P_F4AZ`"@T%S__
M-!@_W>A='/4(``)`-'P"`$AZ`"@('`)9-!@`#.A=&F4(``)`0'P"`-.<&_B/
M@"&"0'P"`M.3&_@T'`"&BGPA8D!\`@33DQOX-!P`@HI\(4)`?`(&TY,;^#0<
M`(:*?"$B0'P""-.3&_@T'`"0BGPA`D!\`@K3DQOX-!P`BHI\(.(T'``$:]P_
MF4AZ`"@T%S__-!@_C>A=&]4(``)`-'P"`$AZ`"@('`)9-!@`4NA=&44(``)`
M*V````@!`EPWG``0#X`0DS1\`@!KW#^92'P`2&O</Y%(>@`P(XL@`#>9#SA(
M>``P"!,"5^A=%LT(``)`Z``#&C1\`4`('`):Z%\"/0@``D#H```R-'P!0#1S
M`@`('`):"!,"64AX`"#H7P,%"``"0#1\`@!(>@`H"!P"62,$``#H71@U"``"
M0&A\`"!(?``@AX!??0@``D!(>@`HZ%T:/0@``D`CA```-Y,!\#1\`!`*?`H<
M-',!0`@<`EH($P)9Z%\*;0@``D`,8!*8Z```J@QX$)S7G`@A-'0`Z`N4"A0,
M>!"5(F0``#1\`!`*?`H<"KP*'#><`?`/@!`<TYP;^`@<`E,(%`):(XL@`#>9
M#U@($P)8Z%T5#0@``D`,>!"<-YP``@Q\$I@,>!"3-!P`)HI\7S4(``)`8&`!
M."M@```T/``0#X`0DS1\`.AKW#^92'P`2&O</Y%(>@`P(XL@`#>9#SA(>``P
M"!,"5^A=%%T(``)`Z```JB.+(``WF@O@(XL@`#>9#2#H7@'I"``"0"M@```(
M`0)<-YP`$`^`$(3H71)U"``"0&O</YE(?`!(:]P_D4AZ`#`CBR``-YD/:$AX
M`#`(!`)7Z%T3I0@``D`CBR``-YH+6$AY`##H7@%!"``"0$AZ`##H7PPM"``"
M0$A\`#`B9```-G,"*`AS"A,.?!*`("0``#0A`B@(80H!#"`0G$AB/]DH9```
M2"0",#1^`(!/PS^!Z$#``FO"/]D(`P)!"!X"0V_!`8!H9`$`:'H_N6AY/[$,
M8!*82'H_N>A=#K4(``)`:'P`*$A\`"B'@"*2Z``"$DA\`"`WG``F"!P"6B.+
M(``WF0N0Z%T1'0@``D"'@"'22'P`(#><`"8('`):(XL@`#>9#XCH71#="``"
M0(>`(9)(>C^YZ%T0_0@``D`('`)$2'P`(#><`"8('`):Z%T0S0@``D`+A`H<
M-YP`!`Q\$I`,<!"<"!P"6NA=$S4(``)`#'P2F$A\`"`WDP`F#'@0FB.+(``W
MF0^02'@_N0@3`E?H71$E"``"0#1\`#`,>!":"!P"6>A`!.0(``)`AY\@6DAS
M`%`CAR``"Y,"$R."``"*?"`R2'P_L8>`("(,>!":-!D``NA?';4(``)`Z```
M$@QX$)KH714="``"0`QX$)KH70]E"``"0`Q@$IA(>@`HZ%T/A0@``D!H?``@
M2'P`((^`/;4(``)`2'H`*.A=#FT(``)`2'P_N8>`(!)(>C^YZ%T2Q0@``D!(
M8C_92&0!`#1^`(!/PS^!Z$#``FO"/]D(`P)!"!X"0V_!`(!H>C^Y2'H_N>A>
M#[D(``)`#'P2F`QX$)KH7@Z1"``"0`Q\$I#H7A=Q"``"0(>`(*I(?#^YAX`@
MFDA\/[D/@!`<TYP?^(>`('H,<!":(XL@`#>9#P#H70]E"``"0`@<`E,,<!"<
MBGP@.DAZ/[DT&0`"Z%\;Q0@``D`,>!":-!D``.A?&Z4(``)`2&(_V31^`(!/
MPS^!Z$#``FO"/]D(`P)!"!X"0V_!`0!H9``@:'D_L30:``#H70_%"``"0`^`
M$)P('`):Z%T*90@``D`('`):Z%T*;0@``D`/@!"<#X@0A#0:``#H70]E"``"
M0`^`$)P('`):Z%T*!0@``D`('`):Z%T230@``D`/@!`<TYP;^&"<`#`T&@``
MZ%T._0@``D`/@!"<"!P"6NA="9T(``)`"!P"6NA=":4(``)`#X`0G`^($(0T
M&@``Z%T.G0@``D`/@!"<"!P"6NA="3T(``)`"!P"6NA=$.4(``)`#X`0G$N<
M`"#3G!D7TYP;\&2<`#0T&@``Z%T.)0@``D`/@!"<"!P"6NA=",4(``)`"!P"
M6NA=",T(``)`#X`0G`^($(0T&@``Z%T-Q0@``D`/@!"<"!P"6NA="&4(``)`
M"!P"6B.+(``WF0WX-!@``.A=")4(``)`:)P`.#0:``#H70U5"``"0`^`$)P(
M'`):Z%T']0@``D`('`):Z%T'_0@``D`/@!"<#X@0A#0:``#H70SU"``"0`^`
M$)P('`):Z%T'E0@``D`('`):Z%T.'0@``D`/@!"<:)P`0#0:``#H70R5"``"
M0`^`$)P('`):Z%T'-0@``D`('`):Z%T'/0@``D`/@!"<#X@0G`Q\$I@T&@``
MZ%T,+0@``D`/@!"<"!P"6NA=!LT(``)`"!P"6NA=#/4(``)`#X`0G(>`(&HT
M&@``Z%T+S0@``D`/@!"<"!P"6NA=!FT(``)`"!P"6NA=#)4(``)`#X`0G$N<
M`-@,?!*0Z````@Q@$I`,<!"<#'@0DVI\`$@T&@``Z%T+/0@``D`/@!"<"!P"
M6NA=!=T(``)`"!P"6NA=!>4(``)`#X`0G`^($)QK@`!0-!H``.A="M4(``)`
M#X`0G`@<`EKH705U"``"0`@<`EKH705]"``"0`^`$)P/B!"<:X``6#0:``#H
M70IM"``"0`^`$)P('`):Z%T%#0@``D`('`):Z%T%%0@``D`/@!"<#X@0A#0:
M``#H70H-"``"0`^`$)P('`):Z%T$K0@``D`('`):Z%T)E0@``D`/@!"<:)P`
M8$AB/]E(9``@-'X`@$_#/X'H0,`":\(_V0@#`D$('@)#;\$`@&AY/[$T&@``
MZ%T)70@``D`/@!"<"!P"6NA=`_T(``)`"!P"6C09/__H70G]"``"0#0:``#H
M70D%"``"0`^`$)P('`):Z%T#I0@``D`('`)3(XL@`#><#Z`/@!"<"!,"6@@<
M`EDT&```Z%T%O0@``D!(8C_9-'X`@$_#/X'H0,`":\(_V0@#`D$('@)#;\$!
M`&AY/[%H8``@-!H``.A="#4(``)`#X`0G`@<`EKH70+5"``"0`@<`EKH708=
M"``"0`@<`E,T'``"#GP2`".+(``WF@NHZ%T3?0@``D`,?!*8#'@0G(>`($H,
M>!"<#X`0'-.3'_@T'`!BBGP@(@QX$)PWG``"#X`0'-.<'_B'@"`*Z%X)Z0@`
M`D`T&@``Z%T'-0@``D`/@!"<"!P"6NA=`=4(``)`"!P"6B.+(``WF0^H-!@`
M`C07`!;H702]"``"0&A\`$A(?`!(AX`C8DA\`$@/F!"<2YP`,&A\`$`T'``"
M:'P`*.@``@HT&@``Z%T&=0@``D`/@!"<"!P"6NA=`14(``)`"!P"4TA\`"@W
MG#__"!,"6DAY`$`('`)8-!<``.A=!:T(``)`:'P`.$A\`#B'@"&B*V`@`#0\
M!F`/@!"32'P`*-><"$(+DPH<#X`0G&A\`'!(?``X#X`0G`^0$),T'`@`"Y,"
M'(>`(")(?``X#X`0G`^8$)QH?`!HZ```@C0:``#H705%"``"0`^`$)P('`):
MZ%T?X0@``D`('`)32'P`.`^`$)P($P):"!P"6308```T%P`$Z%T$O0@``D!H
M?`!H2'H`<$AY`&CH70'U"``"0(^`(%I(?``@-YP``FA\`"!(?``H-YP``FA\
M`"@K8"``-#P&6`^`$)-(?``HBY-]Q0@``D`K8"``-#P&6`^`$)PWDS__2'P`
M((I\(+HT'``":'P`*.@``'(T&@``Z%T#[0@``D`/@!"<"!P"6NA='HD(``)`
M"!P"6DAY`$#H70`M"``"0&A\`#!(?``H-YP``FA\`"@K8"``-#P&6`^`$)-(
M?``HBY-_70@``D`T&@``Z%T#10@``D`/@!"<"!P"6NA='>$(``)`"!P"6B.+
M(``WF0^X-!@``C07``KH70#-"``"0&A\`$A(?`!(AX`A,C0:``#H70*]"``"
M0`^`$)P('`):Z%T=60@``D`('`)32'P`2`^8$)P/@!"<"!,"6@@<`EDCBR``
M-Y@/P.A='ND(``)`2'P`2`^8$)P/@!"<#Y`0DR.```@+DP(<AX`@<C0:``#H
M70']"``"0`^`$)P('`):Z%T<F0@``D`('`)32'P`2`^8$)P/@!"<"!,"6@@<
M`EGH703]"``"0#0:``#H70&%"``"0`^`$)P('`):Z%T<(0@``D`('`):(XL@
M`#>9#]`T&``"-!<`"NA='PD(``)`:'P`2$A\`$B'@"%J#&`2D".+(``WF@MP
MZ%T,I0@``D`,?!*0#'`0G(>`(((T&@``Z%T`O0@``D`/@!"<"!P"6NA=&UD(
M``)`"!P"4TA\`$@/F!"<#X`0G`@3`EH('`)9#'`0F.A='/$(``)`Z```HC0:
M``#H70`U"``"0`^`$)P('`):Z%T:T0@``D`('`)32'P`2`^8$)P/@!"4*V`@
M``@!`EPWG`9@#X`0G`^`$)P($P):"!0"60@<`ECH70:E"``"0#0:``#H71^)
M"``"0`^`$)P('`):Z%T:*0@``D`('`):Z%T=<0@``D`/@!(`-!H``.A='S$(
M``)`#X`0G`@<`EKH71G1"``"0`@<`EKH70"="``"0`^`$H`CBR``-YH+6.A=
M"HT(``)`"!P"4RM@(``(`0)<-YP&4`^3$H`K8"``"`$"7#><!E`/@!"<CX`B
MZBM@(``T/`9@#X`0G`@<`EKH7QB)"``"0`@<`E,K8"``"`$"7#><!E`/DQ*`
M2'P`2`^8$)P/@!"<#Y`0DS0<"``+DP(<AX`@*DA\`$@/F!"<#X`0G`^8$)QH
M?`!@Z```BC0:``#H71VI"``"0`^`$)P('`):Z%T820@``D`('`)32'P`2`^8
M$)P/@!"<"!,"6@@<`EDT&```-!<`!.A='1D(``)`:'P`8"M@(``T/`9@#X`0
MG$AZ`&`('`)9Z%T;^0@``D!H?``H*V`@``@!`EPWG`9@#X`0G`^`$)QH?`!8
M2'P`2`^8$)P/@!"<#Y`0DS0<"``+DP(<AX`@*DA\`$@/F!"<#X`0G`^8$)QH
M?`!0Z```BC0:``#H71Q!"``"0`^`$)P('`):Z%T6X0@``D`('`)32'P`2`^8
M$)P/@!"<"!,"6@@<`EDT&```-!<`!.A=&[$(``)`:'P`4".+(``WF@_82'D`
M6$AX`%!(=P`HZ%T=D0@``D`K8"``-#P&4`^`$)P('`):-!D#VNA=%?D(``)`
M:'P`*$A\`"B'@""22',`*#0<`"*"?"!Z2'P`*(>?(&HK8"``-#P&8`^`$)P/
M@!"4*V`@`#0\!E`/@!"3(XLP`#>:`#@(%`)9"!,"6$AW`"CH71RI"``"0$AB
M/]DT?@"`3\,_@>A`P`)KPC_9"`,"00@>`D-OP0"`-!H``.A=&E$(``)`#X`0
MG`@<`EKH713Q"``"0`@<`EKH70`U"``"0#0:``#H71H!"``"0`^`$)P('`):
MZ%T4H0@``D`('`)3(XLP`#><`0@/@!"4(XL@`#><#?AKW#^9:\`_D0@3`EHC
MBS``-YD`V`@4`E@CBR``-Y<-^.A=&\$(``)`2&(_V31^`(!/PS^!Z$#``FO"
M/]D(`P)!"!X"0V_!`0!H>C^Y:'D_L6AX/ZDT?#^Y-',_L31T/ZD('`):"!,"
M60@4`ECH71=)"``"0".+,``WG`$@#X`0E".+,``WG`$H#X`0DR.+,``WG`$H
M#X`0G`@4`EH($P)9"!P"6.A`"/@(``)`-!H``.A=%D$(``)`#X`0'-.<'_B/
M@"#ZZ%T3&0@``D`('`)3*V`@``@!`EPWG`9(#Y,2@"M@(``(`0)<-YP&2`^`
M$)R/@"`2-!H``NA=%?$(``)`*V`@`#0\!D@/@!"<"!P"6NA=&:$(``)`-!H`
M`.A=%VD(``)`#X`0G`@<`EKH71()"``"0`@<`EKH71,1"``"0`^`$@`T&@``
MZ%T7$0@``D`/@!"<"!P"6NA=$;$(``)`"!P"6NA=&)D(``)`"!P"4PY@$!S3
MG!OXUY\</].<&_@.?!(`-!H``.A=%I$(``)`#X`0G`@<`EKH71$Q"``"0`@<
M`EKH71@9"``"0`@<`E,.8!`<TYP;^->?'!_3G!OX#GP2`$A\/[DWG``*:'P`
M*#0<``!H?``@2'P`($A]`"@/W!*!#]T2B2_!$!8RP*H7,`!(%C+V#A<T`0`"
M8&$`,".+,``WG`$P+X`0%C+V#`\P`"0@Z````F!@`#!`<P`P-!P``@N3`IS3
MG!OXCX`@&B./$``WF@3PZ%T7,0@``D!(?#^Y-YP`"M><"$(('`):Z%T080@`
M`D`('`)3*V`@``@!`EPWG`9@#Y,2@"M@(``(`0)<-YP&8`^`$)-(?#^Q#X`0
MG`Y\$H`K8"``"`$"7#><!F`/@!"<-Y,`"".+,``WG`$0#GP2@"M@(``(`0)<
M-YP&8`^`$)PWDP`0*WSO_P@!`EPWG`)X#GP2@"M@(``(`0)<-Y,&6#0<``8.
M?!*`*V`@``@!`EPWG`9@#X`0DRM@(``(`0)<-YP&6`^`$)S7G`A""Y,*$R.+
M,``WG`$8#GP2@"M@(``(`0)<-YP&6`^`$)PWDP`"*V`@``@!`EPWG`98#Y,2
M@#0<``(,?!*0Z```LBM@(``T/`9@#X`0E"M@(``T/`98#X`0DPQP$)P+DPH<
MEY,``@@3`ES7G`O>"GP$'-><"$(+E`H42',_L0QP$)S7G`A""Y,*'`^`$)P.
MG!*`#'`0G#><``(,?!*02',_N0QP$)R+DW\M"``"0"M@(``T/`9@#X`0E$AS
M/[DK8"``-#P&6`^`$)P+DPH<EY,``@@3`ES7G`O>"GP$'-><"$(+E`H<#X`2
M@"M@(``T/`9(#X`0E4AS/[DK8"``-#P&6`^`$)P+DPH<-Y,__RM@(``T/`9@
M#X`0E".+,``WG`%`#X`0G&O`/YD(%0):"!P"60@3`E@(%`)7Z%T-20@``D`,
M?!*8#'@0G(^`(#(K8"``-#P&2`^`$)P('`):Z%T3(0@``D`,?!*8*V`@`#0\
M!D@/@!"<"!P"6NA=$"D(``)`(XL@`#>:"\CH71Q!"``"0(^`(+(K8"``-#P&
M4`^`$)R/@"!"(XL@`#>:"UCH71OY"``"0`@<`E,K8"``"`$"7#><!E`/DQ*`
M*V`@`#0\!E`/@!"<AX`@*BM@(``T/`90#X`0G`@<`EKH7QYQ"``"0"M@(``T
M/`9(#X`0G`@<`EKH70XY"``"0.A=$6D(``)`#'@0G$AB/]DT?@"`3\,_@>A`
MP`)KPC_9*V```$@\!=B'@"`(-!<```^`$)=+PC_9Z!T,&0@``D`(``)`Z$#`
M`FO"/]EOR0$`"!H"26O(/PD(&0)(:\<_$0@8`D=KQC\9:\4_(6O$/RD($P)$
M:],_P>A="(EKPS\Q"`0"4RM@``!(-07@*V```$@F!>@(U005TJ4?HH2@(%`T
M`P``#,,@E@@3`D0T8P`""`D"6@@(`ED(!P)8Z^``V`@?`D*(9;^U"`0"4TO"
M/ME+R#\)2\<_$4O&/QE+Q3\A2\0_*4O#/S'H0,``3\D_`6O"/]D(&0)82\(_
MV0@:`EDT&@`&Z!T.(0@``D`(``)`:\(_V0@9`EA+PC_9"!H"630:``;H'0D!
M"``"0`@``D#'UL`2UL`<'@[($),.P!"6ZL#``&O"/]%KPC_9;\0`@&O#/XF'
M7R`0:],_P30<'_Z#7(`B"!H"7$O"/UE+PS^)Z$#``$_$/X''VM_-"!H"0RM@
M``!(/070U&`<'@Q@$)HW5``@BIT_G0@:`EPK8```2#<%P`[@$)R'@"`X(L</
M@0^H$)H.X!"6#&@0F>O_'MT('P)"Z!\?-0Q@$)H.D1"42I\`0`K?`APBH`T!
M@Y4@*#:8`$`.F1"?-I@_^0K?`AR+E3[=-!H__]/U&Y;3_!N_UYP)2M/V&?#3
M]!O_UM8)>]:4"A`*M`)4"Y0"5`K4`E32G!GPAX`@$-:T"$+6GQXQUK0(0@JX
M"A0K8```2#P%R#:4`!`/E!*`#[D0E0^5$HC7GQP>Z!\>K0[\$H`K?___:\(_
MV6_%`0!KQ#\):\,_$30C#@`,>1"%Z%\=E0@%`EHT&C__Z%\=?0@<`D2`G"!8
M-&,_^0@%`E;K_QTE"!\"0DQE/_GH7QT]"`4"6C0:/__H7QTE"!P"1(B</[4(
M!0)62\(^V4O$/PE+PS\1Z$#``$_%/P%KPC_9-]X`@$O"/UGH0,``-]X_@>A`
MP`)KPC_9;\0`@&O3/\$($P)$Z%T-N0@``D!+PC]9"`0"4^A`P`!/Q#^!````
M```!ZAH``>ER``'GN@`!Z2H``@`!`````'!E<FQX<VDN8P```$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@```>C2+W!R;V,O<V5L9B]E>&4``"\````Z
M````+W!R;V,O)6DO)7,`97AE`%!!4E]414U0`````%!!4E]04D]'3D%-10``
M```N````)7,E<R5S``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%2
M7T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T%21T,`````
M4$%27T%21U9?,```4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-
M4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,
M7T-,14%.`````%!!4E]#3$5!3CT``#$```!?7T5.5E]005)?0TQ%04Y?7R`@
M("`@("`@("`@("`@(`````!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)2
M05)97U!!5$@`````4$%42`````!$64Q$7TQ)0E)!4EE?4$%42```````````
M`7:X``%VR``!=M```7;@``%VZ``!=OQ435!$25(``%1%35!$25(`5$5-4```
M``!435````%V5``!=Q@``7<@``%W*``!=S```7;\0SI<5$5-4``O=&UP````
M```!=TP``7=4``%UR``!=OQ54T52`````%5315).04U%`````'!A<BT`````
M4UE35$5-```E<R5S)7,E<P`````E<R5S8V%C:&4M)7,E<P``)3`R>``````E
M<R5S=&5M<"TE=25S````+BX``"5S+R5S``````'GDD%21U8`````&````'!E
M<FP`````,````"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("T@86)O<G1I
M;F<@=VET:"`E:2X*`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('1E;7!O<F%R
M>2!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*
M````26YT97)N86QS.CI005(Z.D)/3U0```````'H*BUE```M+0````'HX@`!
MY]I!S____X`````!YYH`````<&%R+G!L```C(2]U<W(O8FEN+W!E<FP*"F5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K86=E
M(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N
M>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*
M(VQI;F4@,34Y"@IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER92!&
M:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(')E
M<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO=FEN
M9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ9FEN
M9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?
M=&5M<"D["B`@("!R;61I<B`D<&%R7W1E;7`["B`@("!R;61I<B`D=&]P9&ER
M.PH*("`@(&EF("@M9"`D<&%R7W1E;7`I('L*("`@("`@("`C(%-O;65T:&EN
M9R!W96YT('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R
M>2X@(%1H:7,*("`@("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F
M;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C
M(&QI8G)A<FEE<R!A;F0@97AE8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5
M;FQI;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA
M;F0@<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@
M<')O8V5S<RX*"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`H@
M("`@("`@("`@("!414U03$%412`]/B`G=&UP6%A86%@G+`H@("`@("`@("`@
M("!$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"B`@
M("`@("`@("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@("`@("`@(%5.3$E.
M2R`]/B`P+`H@("`@("`@("D["@H@("`@("`@(",@0F5C875S92!T:&4@<&%R
M7W1E;7`@9&ER96-T;W)Y(&ES(&=O:6YG('1O(&)E(&1E;&5T960@:6X@80H@
M("`@("`@(",@8F%C:V=R;W5N9"!P<F]C97-S+"!T:&4@<&%R96YT('!R;V-E
M<W,@:60@;6%Y(&)E(')E=7-E9"!B969O<F4@=&AE"B`@("`@("`@(R!B86-K
M9W)O=6YD('!R;V-E<W,@8V]M<&QE=&5S+B`@5&\@96YS=7)E('1H870@=&AE
M('1E;7!O<F%R>0H@("`@("`@(",@9&ER96-T;W)Y(&1O97,@;F]T(&=E="!R
M975S960@=VAI;&4@:70@:7,@8F5I;F<@9&5L971E9"P@=')Y('1O"B`@("`@
M("`@(R!R96YA;64@:70@=&\@82!N86UE('1H870@:7,@<F5L871E9"!T;R!T
M:&4@=&5M<&]R87)Y('-C<FEP="!F:6QE+@H*("`@("`@("!M>2`D=&UP;F%M
M92`]("A&:6QE.CI3<&5C+3YS<&QI='!A=&@H)'1M<"T^9FEL96YA;64I*5LR
M73L@(R!F:6QE;F%M90H@("`@("`@("1T;7!N86UE(#U^(',O7"Y;7BY=*B0O
M+F1I<B\["B`@("`@("`@;7D@)&YE=T1I<B`]($9I;&4Z.E-P96,M/F-A='!A
M=&@H"B`@("`@("`@("`@("A&:6QE.CI3<&5C+3YS<&QI='!A=&@H)'!A<E]T
M96UP*2E;,"XN,5TL("1T;7!N86UE*3L*("`@("`@("!I9B`H<F5N86UE("1P
M87)?=&5M<"P@)&YE=T1I<BD@>PH@("`@("`@("`@("!O=71S*")296YA;65D
M("1P87)?=&5M<"!T;R`D;F5W1&ER(BD["B`@("`@("`@("`@("1P87)?=&5M
M<"`]("1N97=$:7(["B`@("`@("`@?0H*("`@("`@("!I9B`H)%Y/(#U^(&TO
M=VEN,S(O:2D@>PH@("`@("`@("`@("!P<FEN="`D=&UP("(*.FQO;W`*<FUD
M:7(@+W$@+W,@7"(D<&%R7W1E;7!<(@II9B!E>&ES="!<(B1P87)?=&5M<%PB
M(&=O=&\@;&]O<`IR;61I<B!<(B1T;W!D:7)<(@IR;2!<(B(@+B`D=&UP+3YF
M:6QE;F%M92`N(")<(@HB.PH@("`@("`@("`@("!C;&]S92`D=&UP.PH@("`@
M("`@("`@("!M>2`D<')O8SL*("`@("`@("`@("`@5VEN,S(Z.E!R;V-E<W,Z
M.D-R96%T92@*("`@("`@("`@("`@("`@("1P<F]C+"`D14Y6>T-/35-014-]
M+`H@("`@("`@("`@("`@("`@(B1%3E9[0T]-4U!%0WT@+V,@7"(B("X@)'1M
M<"T^9FEL96YA;64@+B`B7"(@/FYU;"`R/FYU;"`B+`H@("`@("`@("`@("`@
M("`@,2P@3D]234%,7U!224]225197T-,05-3+"`B+B(*("`@("`@("`@("`@
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN="`D=&UP("(C
M(2]B:6XO<V@*=VAI;&4@6R`M9"`G)'!A<E]T96UP)R!=.R!D;PH@("!R;2`M
M<F8@)R1P87)?=&5M<"<*9&]N90IR;61I<B`G)'1O<&1I<B<*<FT@)R(@+B`D
M=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L
M)'1M<"T^9FEL96YA;64["B`@("`@("`@("`@(&UY("1C;60@/2`D=&UP+3YF
M:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PH@("`@("`@("`@("!C
M;&]S92`D=&UP.PH@("`@("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@
M?0H@("`@("`@(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@
M=&\@<&5R9F]R;2!C;&5A;G5P*2D["B`@("!]"GT@?0H*0D5'24X@>PH@("`@
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF
M("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P
M?2`I('L*("`@($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q
M("XN("1%3E9[4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%2
M1U9?,'T["GT*96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@
M(&1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY
M("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@
M:68@:6YV;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?
M<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@
M7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI
M+R`_("<N97AE)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@
M+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE
M*"D["E]S971?<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG
M(&%N9"!E>'1R86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R
M=%]P;W,L("1D871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]705).7U]]
M(#T@<W5B('M].PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@
M;V8@9&%T82!S96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*
M("`@('-E96L@7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@
M("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E
M:R!?1D@L("TQ,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E
M:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?
M1D@L("1B=68L(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M"B`@("`C('U]?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M
M96UO<GD@>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B
M=68@97$@(D9)3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@
M("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@
M("`@("!M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP
M86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C
M(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z
M('5N9&5F.PH@("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@
M/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L
M("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PH*("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A
M?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O
M=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@
M("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O
M=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@
M("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W
M-34L("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@
M("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA
M;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]
M("D@>PH@("`@("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I
M;&4H*0H@("`@("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-
M4'TO)&)A<V5N86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D
M9FEL96YA;65<;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@
M)&9I;&5N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T
M*3L*("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C
M;&]S92`D;W5T.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@
M("`@("`@("!B=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D
M8W)C+`H@("`@("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@
M("`@("`@('T["B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T
M.PH@("`@?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@
M("`@("`@;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U
M<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F
M:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O
M('L*("`@("`@("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H
M:V5Y<R`E<F5Q=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N97AT('5N
M;&5S<R`O7%$D;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K97D@/2`D
M7SL@;&%S=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE=&4@)')E
M<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@
M;W(@<F5T=7)N.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O
M)&9I;&5N86UE+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%
M04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@
M("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@
M("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F
M:"`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F:"P@,"P@
M,"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F
M:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@
M*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@
M("`@("`@("`@("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@
M("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@
M("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@
M("`@("`@('T*"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@
M8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C
M($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA
M;&EZ92!S:&%R960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,
M;V%D97(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A
M<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T
M)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@
M(')E<75I<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R
M;W5P(&EN"B`@("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E
M<F5Q=6ER95]L:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N
M<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@
M=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T10
M04XO*2!["B`@("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE
M<B!E>&5C=71A8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL
M96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@
M("`@("`@("`@("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE
M+G!L(&9I;&4Z"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U;FQE<W,@
M)&)U9B!E<2`B4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@
M7T9(*2`M(#0["GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN9R![>WL*
M;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C
M:&5?;F%M92D["@HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT[
M"@HC($1O;B=T('-W86QL;W<@87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E>&5C
M=71A8FQE<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"B`@("!M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@("!P("`@8FQI8E]T;U]P
M87(*("`@("`@("!I("`@:6YS=&%L;%]P87(*("`@("`@("!U("`@=6YI;G-T
M86QL7W!A<@H@("`@("`@(',@("!S:6=N7W!A<@H@("`@("`@('8@("!V97)I
M9GE?<&%R"B`@("`I.PH*("`@(&UY($!A9&1?=&]?:6YC.PH@("`@=VAI;&4@
M*$!!4D=6*2!["B`@("`@("`@)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@:68@*"0Q(&5Q("=))RD@
M>PH@("`@("`@("`@("!P=7-H($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("!]
M"B`@("`@("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("!E=F%L
M(")U<V4@)#(B.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)T$G
M*2!["B`@("`@("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@
M("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@("`@("`D
M;W5T(#T@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G8B<I
M('L*("`@("`@("`@("`@)&)U;F1L92`]("=S:71E)SL*("`@("`@("!]"B`@
M("`@("`@96QS:68@*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`D8G5N9&QE
M(#T@)V%L;"<["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I
M('L*("`@("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@("!]"B`@("`@("`@
M96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("!O<&5N("1L;V=F:"P@
M(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@
M("`@("1C86-H95]N86UE(#T@)#(["B`@("`@("`@?0H*("`@("`@("!S:&EF
M="A`05)'5BD["@H@("`@("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q
M?2D@>PH@("`@("`@("`@("!D96QE=&4@)$5.5GLG4$%27U1%35`G?3L*("`@
M("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@<F5Q=6ER92!005(Z
M.D1I<W0["B`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL
M97-S($!!4D=6.PH@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PH@("`@("`@("`@("!E>&ET.PH@("`@("`@('T*("`@
M('T*"B`@("!U;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"@HC(%A86"`M
M+2!A9&0@+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M
M;V1E("@M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@
M("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE
M("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@
M(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*"B`@("!M>2`D<&%R(#T@
M<VAI9G0H0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@
M)'!A<BD@>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE
M(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F
M:"D["B`@("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O
M<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF
M("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM
M;"<I*2!["B`@("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@
M("`@("`@("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@
M)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@
M('T["@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@
M("!L;V-A;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@
M("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@
M("`@("`@(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T
M(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@
M("!]"@H@("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL
M93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL
M93HZ3U]44E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*
M("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O
M<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*
M("`@(&UY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I
M('L*("`@("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@
M("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D
M97(L("0P*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)65N=BD@>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0[
M"B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\[
M"B`@("`@("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@
M+B`B7U\B.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N
M("(])'9A;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@
M("`@("`@("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I
M("T@;&5N9W1H*"1S970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M
M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@
M("`@(R!7<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L
M92D@>PH@("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H
M*3L*("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN
M8R`]('-O<G0@>PH@("`@("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H
M)&$I"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@(2]"4T1004XO"B`@
M("`@("`@?2!G<F5P('L*("`@("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G
M*2!O<@H@("`@("`@("`@("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL
M:6)E>'!](&%N9`H@("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>W!R:79L:6)E>'!]*3L*("`@("`@("!]($!)3D,["@H@("`@("`@(&EF("@D
M0V]N9FEG>U]D96QI;7T@97$@)UQ<)RD@>R!S>UQ<?7LO?6<@9F]R($!I;F,@
M?0H*("`@("`@("!M>2`E9FEL97,["B`@("`@("`@+UY?/"@N*RDD+R!A;F0@
M)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@("`D9FEL97-[)%]]
M*RL@9F]R('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D;&EB7V5X="`]("1#
M;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M>2`E=W)I='1E;CL*
M"B`@("`@("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PH@("`@("`@
M("`@("!M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@
M;7D@)&1I<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@:68@*"1N86UE(#T@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@("`@("`@("`@("`@
M("`@("`D9FEL92`]("1?.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H+UXH7%$D
M9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@("`@("`@("`@("`@
M*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@("`@("`@("`@("`@
M("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS
M:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@
M("`@("`@("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE
M0V%C:&5[)#%]*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@
M)&YA;64I(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@96QS:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`H)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&YE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD
M;F%M97TK*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@("`@(&]U=',H
M(&IO:6X@(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K:6YG("(I+"!R968@
M)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@("`@("`@("`@("`@
M("!Q<2@B+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@;7D@)&-O
M;G1E;G0["B`@("`@("`@("`@(&EF("AR968H)&9I;&4I*2!["B`@("`@("`@
M("`@("`@("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&]P96X@1DE,
M12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*
M("`@("`@("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@("`@("`@("`@("`@
M("`D8V]N=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@("`@(&-L;W-E($9)
M3$4["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@("`@("`@("`@("`@
M("`@:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z
M<&U\:7A\86PI)"]I.PH*("`@("`@("`@("`@("`@(",@1&\@;F]T(&QE="!8
M4TQO861E<B!P:6-K('5P(&%U=&\O*B!F<F]M(&5N=FER;VYM96YT"B`@("`@
M("`@("`@("`@("`D8V]N=&5N="`]?B!S+V=O=&\@*W)E=')Y("MU;FQE<W,@
M*RXJ+V=O=&\@<F5T<GD[+PH@("`@("`@("`@("`@("`@("`@(&EF(&QC*"1N
M86UE*2!E<2!L8R@B6%-,;V%D97(N<&TB*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@
M("`@("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R
M:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@
M("`D9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E
M<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA
M;64*("`@("`@("`@("`@*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C
M:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP
M<FEN="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@
M("`C($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![
M>WL*("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*
M"B`@("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`[
M"B`@("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M;W5T*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@
M("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!
M,2T^;F5W('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O
M=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@
M("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%
M4E-)3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N
M,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@
M)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]
M"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N
M*&UY("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H
M)&9H*3L*("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@
M("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I
M9V5S="`Z("1M=&EM93L*("`@('T*("`@("1C86-H95]N86UE("X](")<,"(@
M>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@
M)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D
M97(I*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M
M/F-L;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@
M97AI=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F
M:6QE(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@
M=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[
M>PH@("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M
M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E
M<75I<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII
M<#L*("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@
M(&UY("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE
M;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,
M:6)#86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@
M/2`D>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O
M=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*
M"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B
M92!S970@870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@("!N97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA
M;64@/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE
M<W,@)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@("`@
M("`@("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I
M9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N
M9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO
M72LI"B`@("`@("`@("`@("`@("`D"B`@("`@("`@("`@('UX.PH@("`@("`@
M("`@("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D
M97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]
M+"`D97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M("`@("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M
M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@
M("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B*2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@
M("`C('U]?0I]"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R
M=6XL('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;
M+4]O=71F:6QE72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@
M0W)E871E4&%T:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E
M<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T
M:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H
M)UPN+BHG*2D["B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@
M("`@1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I
M.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D
M=6QE<R!["B`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I
M9B`D7D\@;F4@)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q
M=6ER92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q
M=6ER92!S=')I8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER
M92!V87)S.PH@("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(
M96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER
M92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E($9I
M;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U:7)E
M(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E($E/
M.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#
M;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@
M<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U
M:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PH@("`@979A;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(Z.E!R;V-E
M<W,@?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["GT*"B,@
M5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M
M:W1M<&1I<BYC"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("@D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@
M("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@
M(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W
M*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@
M("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X
M="!U;FQE<W,@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@
M("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@
M(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@
M("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@
M("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@
M?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@
M("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*("`@("`@("`D=7-E
M<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P
M871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD
M:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!
M3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@
M("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@
M("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D
M("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@97$@(EPP
M0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PH@
M("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@
M("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@
M("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$
M-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@5V]R
M:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*
M("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG
M97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@
M*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U
M+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R
M;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D
M8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@
M("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD
M:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!C
M;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@
M("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@("1P87)?
M=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L
M("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F
M:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6
M>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE
M("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64[
M"B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL
M96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H
M+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D[
M"B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@IS=6(@7W-E=%]P<F]G
M;F%M92!["B`@("!I9B`H)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!
M4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N86UE(#T@
M)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D[
M"B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@("`@("!I
M9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@("`@("`@
M(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF("@M<R`B
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@)'!R;V=N
M86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D
M0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@("`@(&YE
M>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[
M4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM
M?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@("`@
M("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*"G-U8B!?
M9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!
M4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M(&AA8VL@
M=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D("9#=V0Z
M.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@("`@("`Z("@H
M9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@
M<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]?B!S+UXH
M/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI
M;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0H*
M<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!4E])3DE424%,
M25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*("`@('T@96QS92![
M"B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*("`@('T*"B`@
M("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/
M1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D96QE=&4@)$5.5GLG
M4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%
M04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G+B1??2`]("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?
M0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@("`@:68@*"1%3E9[4$%27U1%
M35!]*2!["B`@("`@("`@9&5L971E("1%3E9[4$%27T-,14%.?3L*("`@('T*
M("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*
M("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L
M96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q
M(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U
M8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I970["B`@("!I9B`H)&QO9V9H
M*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*("`@('T*("`@(&5L
M<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*?0H*<W5B(&EN:71?
M:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P
M(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@
M("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X
M<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]
M"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K
M86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E(&UA:6X["@IR97%U
M:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^
M:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N
M('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER
M96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N
M86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF
M("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)2
M3U(["@HQ.PH*(VQI;F4@,3`Q-PH*7U]%3D1?7PH````6[```%R`(`0`(````
M"```'`@``!R8"`0`"`````@``!R<```<K`@```@````(```<L```'.@(```(
M````"```'.P``!S\"```"`````@``!T````=<`@!`!@````(```==```'H`(
M`0`8```""```'H0``!_,"`$`&````!```!_0```@!`@!`!@````(```@"```
M(]0(`@`8````$```(]@``"1D"`$`&`````@``"1H```EG`@!`!@```00```E
MH```)<0(`0`8````"```)<@``"B\"`$`&````A```"C````I0`@!`!`````(
M```I1```*T`(`0`8````"```*T0``"TX"`$`&````!```"T\```MU`@!`!@`
M```(```MV```3NP(`0`0````.```3O```$]P"`$`$`````@``$]T``!1,`@!
M`!@````(``!1-```4WP(`0`8````"```4X```%4H"`$`&````!```%4L``!5
MA`@!`!@````0``!5B```5PP(`@`8````$```5Q```%^L"`(`&```$#```%^P
M``!A1`@"`!@````8``!A2```8>P(`0`8````"```8?```&4D"`(`&````!``
M`&4H``!EM`@!`!@````(``!EN```;*P(`0`8````$```;+```&U0"`$`&```
M``@``&U4``!R0`@!`!@````0``!R1```<F@(```(````````<FP``')L"```
M`````````')P``!S%`@'``@````0``!S&```<S0(```(````````<S@``'-4
M"```"````````'-8``!S;$@```````````!S<```=(`(`@`(````"```=(0`
M`'3X"`,`"````!```'3\``!U#`@```@````(``!U$```=1`(````````````
M=10``'4X"`$`"`````@!&P,[````$`````'__YU(````*````!```````7I2
M``$$`@$;#!X`````&````!C__YT8```!%`!($W!$@P&$`!$">P````#_____
M`````/____\```````````````$````!`````0```L@````!```"TP````$`
M``+=`````0```QL````!```$+@````P``1;L````#0`!=10````$``$!1```
M``4``0O,````!@`!!)P````*```%S`````L````0`````P`!YW0````5````
M``````(```/8````%`````<````7``$3!`````<``1+@````"````"0````)
M````#&____X``1*`;____P````)O___P``$1F```````````````````````
M``````````````````````````````````````````````````````%UE``!
M=9C_____``%XJ```6K<``6'P``'G=``!;+```>=T````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````.@!"6ZL#```Z($)7JGQ_=UH`<'@#`_^[>K;[O``'FA```
M`````?JH``'ZK````````>=X``'F<``!YG``1T-#.B`H56)U;G1U(#0N,RXQ
M+3%U8G5N='4R*2`T+C,N,0``1T-#.B`H56)U;G1U(#0N,RXQ+3%U8G5N='4R
M*2`T+C,N,0``1T-#.B`H56)U;G1U(#0N,RXQ+35U8G5N='4Q*2`T+C,N,0``
M1T-#.B`H56)U;G1U(#0N,RXQ+35U8G5N='4Q*2`T+C,N,0``1T-#.B`H56)U
M;G1U(#0N,RXQ+35U8G5N='4Q*2`T+C,N,0``1T-#.B`H56)U;G1U(#0N,RXQ
M+3%U8G5N='4R*2`T+C,N,0``1T-#.B`H56)U;G1U(#0N,RXQ+3%U8G5N='4R
M*2`T+C,N,0``1T-#.B`H56)U;G1U(#0N,RXQ+3%U8G5N='4R*2`T+C,N,0``
M1T-#.B`H56)U;G1U(#0N,RXQ+3%U8G5N='4R*2`T+C,N,0``1T-#.B`H56)U
M;G1U(#0N,RXQ+35U8G5N='4Q*2`T+C,N,0``1T-#.B`H56)U;G1U(#0N,RXQ
M+35U8G5N='4Q*2`T+C,N,0``1T-#.B`H56)U;G1U(#0N,RXQ+3%U8G5N='4R
M*2`T+C,N,0`````&``````````$P,2XP,0````````8``````````3`Q+C`Q
M````````!@`````````!,#$N,#$````````&``````````$P,2XP,0``````
M``8``````````3`Q+C`Q````````!@`````````!,#$N,#$`````+G-H<W1R
M=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N:&%S:``N9'EN<WEM`"YD>6YS
M='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L
M82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N4$%225-#+G5N=VEN
M9``N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`
M+F1Y;F%M:6,`+F1A=&$`+F=O=``N8G-S`"YC;VUM96YT`"YN;W1E````````
M````````````````````````````````````````````````````"P````$`
M```"``$!%````10````-```````````````!`````````!,````'`````@`!
M`20```$D````(```````````````!``````````A````!0````(``0%$```!
M1````U@````$``````````0````$````)P````L````"``$$G```!)P```<P
M````!0````$````$````$````"\````#`````@`!"\P```O,```%S```````
M`````````0`````````W;____P````(``1&8```1F````.8````$````````
M``(````"````1&____X````"``$2@```$H````!@````!0````(````$````
M`````%,````$`````@`!$N```!+@````)`````0`````````!`````P```!=
M````!`````(``1,$```3!````]@````$````%@````0````,````9P````$`
M```&``$6W```%MP```!(```````````````$`````````&T````!````!@`!
M%R0``!<D``!=\```````````````!`````````!S`````0````8``744``!U
M%````"@```````````````0`````````>0````$````"``%U0```=4```%XH
M```````````````(`````````($````!`````@`!TV@``--H```"P```````
M```+````!`````0```"0`````0````(``=8H``#6*````!0`````````````
M``0`````````G@````$````"``'6/```UCP````T```````````````$````
M`````*@````!`````P`!YG```-9P````"```````````````!`````````"O
M`````0````,``>9X``#6>`````@```````````````0`````````M@````$`
M```#``'F@```UH`````$```````````````$`````````+L````&`````P`!
MYH0``-:$````\`````4`````````!`````@```#$`````0````,``>=T``#7
M=````!P```````````````0`````````8@````$````'``'GD```UY````*\
M```````````````$````"````,H````!`````P`!ZDP``-I,````(```````
M````````!`````0```#/````"`````,``>IP``#:;```$$0`````````````
M``@`````````U`````$`````````````VFP```&P```````````````!````
M`````-T````'`````````````-P<````>````````````````0`````````!
D`````P````````````#<E````.,```````````````$`````
